// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CANNOT_USE_PC_MOVS_A32_H_
#define VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CANNOT_USE_PC_MOVS_A32_H_

const byte kInstruction_movs_ls_r0_0x003fc000[] = {
  0xff, 0x09, 0xb0, 0x93 // movs ls r0 0x003fc000
};
const byte kInstruction_movs_eq_r13_0xff000000[] = {
  0xff, 0xd4, 0xb0, 0x03 // movs eq r13 0xff000000
};
const byte kInstruction_movs_al_r0_0x0002ac00[] = {
  0xab, 0x0b, 0xb0, 0xe3 // movs al r0 0x0002ac00
};
const byte kInstruction_movs_gt_r13_0x002ac000[] = {
  0xab, 0xd9, 0xb0, 0xc3 // movs gt r13 0x002ac000
};
const byte kInstruction_movs_mi_r3_0x000002ac[] = {
  0xab, 0x3f, 0xb0, 0x43 // movs mi r3 0x000002ac
};
const byte kInstruction_movs_ls_r0_0x000000ff[] = {
  0xff, 0x00, 0xb0, 0x93 // movs ls r0 0x000000ff
};
const byte kInstruction_movs_ls_r7_0x0000ab00[] = {
  0xab, 0x7c, 0xb0, 0x93 // movs ls r7 0x0000ab00
};
const byte kInstruction_movs_cc_r11_0x0ff00000[] = {
  0xff, 0xb6, 0xb0, 0x33 // movs cc r11 0x0ff00000
};
const byte kInstruction_movs_vs_r5_0xc000003f[] = {
  0xff, 0x51, 0xb0, 0x63 // movs vs r5 0xc000003f
};
const byte kInstruction_movs_gt_r3_0x00ab0000[] = {
  0xab, 0x38, 0xb0, 0xc3 // movs gt r3 0x00ab0000
};
const byte kInstruction_movs_hi_r7_0xff000000[] = {
  0xff, 0x74, 0xb0, 0x83 // movs hi r7 0xff000000
};
const byte kInstruction_movs_vc_r10_0xff000000[] = {
  0xff, 0xa4, 0xb0, 0x73 // movs vc r10 0xff000000
};
const byte kInstruction_movs_hi_r10_0x002ac000[] = {
  0xab, 0xa9, 0xb0, 0x83 // movs hi r10 0x002ac000
};
const byte kInstruction_movs_ne_r9_0x00ff0000[] = {
  0xff, 0x98, 0xb0, 0x13 // movs ne r9 0x00ff0000
};
const byte kInstruction_movs_ge_r3_0xf000000f[] = {
  0xff, 0x32, 0xb0, 0xa3 // movs ge r3 0xf000000f
};
const byte kInstruction_movs_hi_r0_0x000ff000[] = {
  0xff, 0x0a, 0xb0, 0x83 // movs hi r0 0x000ff000
};
const byte kInstruction_movs_mi_r2_0x00002ac0[] = {
  0xab, 0x2d, 0xb0, 0x43 // movs mi r2 0x00002ac0
};
const byte kInstruction_movs_ge_r6_0x000ab000[] = {
  0xab, 0x6a, 0xb0, 0xa3 // movs ge r6 0x000ab000
};
const byte kInstruction_movs_mi_r9_0x00ff0000[] = {
  0xff, 0x98, 0xb0, 0x43 // movs mi r9 0x00ff0000
};
const byte kInstruction_movs_cs_r2_0x000ff000[] = {
  0xff, 0x2a, 0xb0, 0x23 // movs cs r2 0x000ff000
};
const byte kInstruction_movs_lt_r5_0x003fc000[] = {
  0xff, 0x59, 0xb0, 0xb3 // movs lt r5 0x003fc000
};
const byte kInstruction_movs_al_r1_0x000ff000[] = {
  0xff, 0x1a, 0xb0, 0xe3 // movs al r1 0x000ff000
};
const byte kInstruction_movs_mi_r6_0x000000ab[] = {
  0xab, 0x60, 0xb0, 0x43 // movs mi r6 0x000000ab
};
const byte kInstruction_movs_pl_r9_0xac000002[] = {
  0xab, 0x93, 0xb0, 0x53 // movs pl r9 0xac000002
};
const byte kInstruction_movs_hi_r8_0x000ff000[] = {
  0xff, 0x8a, 0xb0, 0x83 // movs hi r8 0x000ff000
};
const byte kInstruction_movs_vs_r0_0x00002ac0[] = {
  0xab, 0x0d, 0xb0, 0x63 // movs vs r0 0x00002ac0
};
const byte kInstruction_movs_ls_r4_0xab000000[] = {
  0xab, 0x44, 0xb0, 0x93 // movs ls r4 0xab000000
};
const byte kInstruction_movs_vs_r6_0x000ab000[] = {
  0xab, 0x6a, 0xb0, 0x63 // movs vs r6 0x000ab000
};
const byte kInstruction_movs_vc_r13_0x0000ab00[] = {
  0xab, 0xdc, 0xb0, 0x73 // movs vc r13 0x0000ab00
};
const byte kInstruction_movs_mi_r0_0xab000000[] = {
  0xab, 0x04, 0xb0, 0x43 // movs mi r0 0xab000000
};
const byte kInstruction_movs_vs_r9_0x0ab00000[] = {
  0xab, 0x96, 0xb0, 0x63 // movs vs r9 0x0ab00000
};
const byte kInstruction_movs_pl_r0_0x00003fc0[] = {
  0xff, 0x0d, 0xb0, 0x53 // movs pl r0 0x00003fc0
};
const byte kInstruction_movs_al_r2_0x0000ff00[] = {
  0xff, 0x2c, 0xb0, 0xe3 // movs al r2 0x0000ff00
};
const byte kInstruction_movs_gt_r11_0x00000ab0[] = {
  0xab, 0xbe, 0xb0, 0xc3 // movs gt r11 0x00000ab0
};
const byte kInstruction_movs_vs_r10_0xac000002[] = {
  0xab, 0xa3, 0xb0, 0x63 // movs vs r10 0xac000002
};
const byte kInstruction_movs_cs_r3_0x0002ac00[] = {
  0xab, 0x3b, 0xb0, 0x23 // movs cs r3 0x0002ac00
};
const byte kInstruction_movs_vc_r13_0x000000ab[] = {
  0xab, 0xd0, 0xb0, 0x73 // movs vc r13 0x000000ab
};
const byte kInstruction_movs_cs_r11_0x003fc000[] = {
  0xff, 0xb9, 0xb0, 0x23 // movs cs r11 0x003fc000
};
const byte kInstruction_movs_vs_r14_0x0000ab00[] = {
  0xab, 0xec, 0xb0, 0x63 // movs vs r14 0x0000ab00
};
const byte kInstruction_movs_eq_r11_0xfc000003[] = {
  0xff, 0xb3, 0xb0, 0x03 // movs eq r11 0xfc000003
};
const byte kInstruction_movs_pl_r13_0x00000ab0[] = {
  0xab, 0xde, 0xb0, 0x53 // movs pl r13 0x00000ab0
};
const byte kInstruction_movs_ge_r4_0xb000000a[] = {
  0xab, 0x42, 0xb0, 0xa3 // movs ge r4 0xb000000a
};
const byte kInstruction_movs_pl_r12_0x00003fc0[] = {
  0xff, 0xcd, 0xb0, 0x53 // movs pl r12 0x00003fc0
};
const byte kInstruction_movs_le_r4_0x0000ff00[] = {
  0xff, 0x4c, 0xb0, 0xd3 // movs le r4 0x0000ff00
};
const byte kInstruction_movs_pl_r4_0x003fc000[] = {
  0xff, 0x49, 0xb0, 0x53 // movs pl r4 0x003fc000
};
const byte kInstruction_movs_hi_r0_0x002ac000[] = {
  0xab, 0x09, 0xb0, 0x83 // movs hi r0 0x002ac000
};
const byte kInstruction_movs_mi_r1_0x00003fc0[] = {
  0xff, 0x1d, 0xb0, 0x43 // movs mi r1 0x00003fc0
};
const byte kInstruction_movs_hi_r9_0xf000000f[] = {
  0xff, 0x92, 0xb0, 0x83 // movs hi r9 0xf000000f
};
const byte kInstruction_movs_al_r11_0x0000ab00[] = {
  0xab, 0xbc, 0xb0, 0xe3 // movs al r11 0x0000ab00
};
const byte kInstruction_movs_ne_r6_0x00ab0000[] = {
  0xab, 0x68, 0xb0, 0x13 // movs ne r6 0x00ab0000
};
const byte kInstruction_movs_lt_r4_0xff000000[] = {
  0xff, 0x44, 0xb0, 0xb3 // movs lt r4 0xff000000
};
const byte kInstruction_movs_pl_r0_0x0ab00000[] = {
  0xab, 0x06, 0xb0, 0x53 // movs pl r0 0x0ab00000
};
const byte kInstruction_movs_ls_r2_0xc000002a[] = {
  0xab, 0x21, 0xb0, 0x93 // movs ls r2 0xc000002a
};
const byte kInstruction_movs_lt_r5_0x00003fc0[] = {
  0xff, 0x5d, 0xb0, 0xb3 // movs lt r5 0x00003fc0
};
const byte kInstruction_movs_mi_r5_0x000003fc[] = {
  0xff, 0x5f, 0xb0, 0x43 // movs mi r5 0x000003fc
};
const byte kInstruction_movs_ls_r11_0xb000000a[] = {
  0xab, 0xb2, 0xb0, 0x93 // movs ls r11 0xb000000a
};
const byte kInstruction_movs_al_r3_0x0000ff00[] = {
  0xff, 0x3c, 0xb0, 0xe3 // movs al r3 0x0000ff00
};
const byte kInstruction_movs_vs_r3_0xfc000003[] = {
  0xff, 0x33, 0xb0, 0x63 // movs vs r3 0xfc000003
};
const byte kInstruction_movs_ne_r1_0xc000002a[] = {
  0xab, 0x11, 0xb0, 0x13 // movs ne r1 0xc000002a
};
const byte kInstruction_movs_eq_r10_0x0003fc00[] = {
  0xff, 0xab, 0xb0, 0x03 // movs eq r10 0x0003fc00
};
const byte kInstruction_movs_eq_r3_0xf000000f[] = {
  0xff, 0x32, 0xb0, 0x03 // movs eq r3 0xf000000f
};
const byte kInstruction_movs_vs_r5_0x000ff000[] = {
  0xff, 0x5a, 0xb0, 0x63 // movs vs r5 0x000ff000
};
const byte kInstruction_movs_ge_r12_0x000000ab[] = {
  0xab, 0xc0, 0xb0, 0xa3 // movs ge r12 0x000000ab
};
const byte kInstruction_movs_vc_r12_0xf000000f[] = {
  0xff, 0xc2, 0xb0, 0x73 // movs vc r12 0xf000000f
};
const byte kInstruction_movs_lt_r11_0x02ac0000[] = {
  0xab, 0xb7, 0xb0, 0xb3 // movs lt r11 0x02ac0000
};
const byte kInstruction_movs_vs_r6_0x003fc000[] = {
  0xff, 0x69, 0xb0, 0x63 // movs vs r6 0x003fc000
};
const byte kInstruction_movs_cs_r8_0x3fc00000[] = {
  0xff, 0x85, 0xb0, 0x23 // movs cs r8 0x3fc00000
};
const byte kInstruction_movs_le_r5_0x0002ac00[] = {
  0xab, 0x5b, 0xb0, 0xd3 // movs le r5 0x0002ac00
};
const byte kInstruction_movs_ls_r9_0x0002ac00[] = {
  0xab, 0x9b, 0xb0, 0x93 // movs ls r9 0x0002ac00
};
const byte kInstruction_movs_al_r4_0x3fc00000[] = {
  0xff, 0x45, 0xb0, 0xe3 // movs al r4 0x3fc00000
};
const byte kInstruction_movs_lt_r5_0x000000ff[] = {
  0xff, 0x50, 0xb0, 0xb3 // movs lt r5 0x000000ff
};
const byte kInstruction_movs_cs_r8_0xc000002a[] = {
  0xab, 0x81, 0xb0, 0x23 // movs cs r8 0xc000002a
};
const byte kInstruction_movs_cs_r0_0x00000ab0[] = {
  0xab, 0x0e, 0xb0, 0x23 // movs cs r0 0x00000ab0
};
const byte kInstruction_movs_cs_r2_0x3fc00000[] = {
  0xff, 0x25, 0xb0, 0x23 // movs cs r2 0x3fc00000
};
const byte kInstruction_movs_vs_r14_0xab000000[] = {
  0xab, 0xe4, 0xb0, 0x63 // movs vs r14 0xab000000
};
const byte kInstruction_movs_ne_r8_0x002ac000[] = {
  0xab, 0x89, 0xb0, 0x13 // movs ne r8 0x002ac000
};
const byte kInstruction_movs_vs_r1_0x003fc000[] = {
  0xff, 0x19, 0xb0, 0x63 // movs vs r1 0x003fc000
};
const byte kInstruction_movs_al_r7_0x003fc000[] = {
  0xff, 0x79, 0xb0, 0xe3 // movs al r7 0x003fc000
};
const byte kInstruction_movs_vs_r7_0x000ab000[] = {
  0xab, 0x7a, 0xb0, 0x63 // movs vs r7 0x000ab000
};
const byte kInstruction_movs_vc_r12_0xb000000a[] = {
  0xab, 0xc2, 0xb0, 0x73 // movs vc r12 0xb000000a
};
const byte kInstruction_movs_eq_r2_0xc000002a[] = {
  0xab, 0x21, 0xb0, 0x03 // movs eq r2 0xc000002a
};
const byte kInstruction_movs_lt_r4_0x0000ff00[] = {
  0xff, 0x4c, 0xb0, 0xb3 // movs lt r4 0x0000ff00
};
const byte kInstruction_movs_eq_r8_0x2ac00000[] = {
  0xab, 0x85, 0xb0, 0x03 // movs eq r8 0x2ac00000
};
const byte kInstruction_movs_hi_r7_0x3fc00000[] = {
  0xff, 0x75, 0xb0, 0x83 // movs hi r7 0x3fc00000
};
const byte kInstruction_movs_mi_r13_0x3fc00000[] = {
  0xff, 0xd5, 0xb0, 0x43 // movs mi r13 0x3fc00000
};
const byte kInstruction_movs_al_r2_0x0002ac00[] = {
  0xab, 0x2b, 0xb0, 0xe3 // movs al r2 0x0002ac00
};
const byte kInstruction_movs_gt_r13_0xab000000[] = {
  0xab, 0xd4, 0xb0, 0xc3 // movs gt r13 0xab000000
};
const byte kInstruction_movs_vs_r3_0x00000ab0[] = {
  0xab, 0x3e, 0xb0, 0x63 // movs vs r3 0x00000ab0
};
const byte kInstruction_movs_mi_r14_0x00000000[] = {
  0x00, 0xe0, 0xb0, 0x43 // movs mi r14 0x00000000
};
const byte kInstruction_movs_vs_r10_0x3fc00000[] = {
  0xff, 0xa5, 0xb0, 0x63 // movs vs r10 0x3fc00000
};
const byte kInstruction_movs_vc_r7_0x0ff00000[] = {
  0xff, 0x76, 0xb0, 0x73 // movs vc r7 0x0ff00000
};
const byte kInstruction_movs_al_r3_0xf000000f[] = {
  0xff, 0x32, 0xb0, 0xe3 // movs al r3 0xf000000f
};
const byte kInstruction_movs_cs_r12_0x03fc0000[] = {
  0xff, 0xc7, 0xb0, 0x23 // movs cs r12 0x03fc0000
};
const byte kInstruction_movs_hi_r14_0xab000000[] = {
  0xab, 0xe4, 0xb0, 0x83 // movs hi r14 0xab000000
};
const byte kInstruction_movs_mi_r13_0x000002ac[] = {
  0xab, 0xdf, 0xb0, 0x43 // movs mi r13 0x000002ac
};
const byte kInstruction_movs_ge_r8_0x2ac00000[] = {
  0xab, 0x85, 0xb0, 0xa3 // movs ge r8 0x2ac00000
};
const byte kInstruction_movs_vc_r14_0x000003fc[] = {
  0xff, 0xef, 0xb0, 0x73 // movs vc r14 0x000003fc
};
const byte kInstruction_movs_mi_r4_0x0000ab00[] = {
  0xab, 0x4c, 0xb0, 0x43 // movs mi r4 0x0000ab00
};
const byte kInstruction_movs_hi_r11_0x0ff00000[] = {
  0xff, 0xb6, 0xb0, 0x83 // movs hi r11 0x0ff00000
};
const byte kInstruction_movs_gt_r8_0x000ff000[] = {
  0xff, 0x8a, 0xb0, 0xc3 // movs gt r8 0x000ff000
};
const byte kInstruction_movs_lt_r1_0x3fc00000[] = {
  0xff, 0x15, 0xb0, 0xb3 // movs lt r1 0x3fc00000
};
const byte kInstruction_movs_mi_r12_0x000000ab[] = {
  0xab, 0xc0, 0xb0, 0x43 // movs mi r12 0x000000ab
};
const byte kInstruction_movs_vs_r12_0x000003fc[] = {
  0xff, 0xcf, 0xb0, 0x63 // movs vs r12 0x000003fc
};
const byte kInstruction_movs_cs_r10_0x000ff000[] = {
  0xff, 0xaa, 0xb0, 0x23 // movs cs r10 0x000ff000
};
const byte kInstruction_movs_mi_r12_0xfc000003[] = {
  0xff, 0xc3, 0xb0, 0x43 // movs mi r12 0xfc000003
};
const byte kInstruction_movs_pl_r8_0x000000ff[] = {
  0xff, 0x80, 0xb0, 0x53 // movs pl r8 0x000000ff
};
const byte kInstruction_movs_lt_r5_0x00002ac0[] = {
  0xab, 0x5d, 0xb0, 0xb3 // movs lt r5 0x00002ac0
};
const byte kInstruction_movs_ge_r0_0xff000000[] = {
  0xff, 0x04, 0xb0, 0xa3 // movs ge r0 0xff000000
};
const byte kInstruction_movs_pl_r0_0xab000000[] = {
  0xab, 0x04, 0xb0, 0x53 // movs pl r0 0xab000000
};
const byte kInstruction_movs_ls_r8_0x000ab000[] = {
  0xab, 0x8a, 0xb0, 0x93 // movs ls r8 0x000ab000
};
const byte kInstruction_movs_al_r12_0x00000ff0[] = {
  0xff, 0xce, 0xb0, 0xe3 // movs al r12 0x00000ff0
};
const byte kInstruction_movs_hi_r5_0x00003fc0[] = {
  0xff, 0x5d, 0xb0, 0x83 // movs hi r5 0x00003fc0
};
const byte kInstruction_movs_vs_r7_0x0003fc00[] = {
  0xff, 0x7b, 0xb0, 0x63 // movs vs r7 0x0003fc00
};
const byte kInstruction_movs_ls_r13_0x0ff00000[] = {
  0xff, 0xd6, 0xb0, 0x93 // movs ls r13 0x0ff00000
};
const byte kInstruction_movs_al_r7_0x000000ab[] = {
  0xab, 0x70, 0xb0, 0xe3 // movs al r7 0x000000ab
};
const byte kInstruction_movs_lt_r6_0x000003fc[] = {
  0xff, 0x6f, 0xb0, 0xb3 // movs lt r6 0x000003fc
};
const byte kInstruction_movs_mi_r9_0xc000002a[] = {
  0xab, 0x91, 0xb0, 0x43 // movs mi r9 0xc000002a
};
const byte kInstruction_movs_ne_r11_0x003fc000[] = {
  0xff, 0xb9, 0xb0, 0x13 // movs ne r11 0x003fc000
};
const byte kInstruction_movs_cs_r4_0x00000ab0[] = {
  0xab, 0x4e, 0xb0, 0x23 // movs cs r4 0x00000ab0
};
const byte kInstruction_movs_vc_r14_0x2ac00000[] = {
  0xab, 0xe5, 0xb0, 0x73 // movs vc r14 0x2ac00000
};
const byte kInstruction_movs_vc_r8_0x2ac00000[] = {
  0xab, 0x85, 0xb0, 0x73 // movs vc r8 0x2ac00000
};
const byte kInstruction_movs_ge_r10_0x003fc000[] = {
  0xff, 0xa9, 0xb0, 0xa3 // movs ge r10 0x003fc000
};
const byte kInstruction_movs_lt_r14_0xb000000a[] = {
  0xab, 0xe2, 0xb0, 0xb3 // movs lt r14 0xb000000a
};
const byte kInstruction_movs_cs_r12_0x000ff000[] = {
  0xff, 0xca, 0xb0, 0x23 // movs cs r12 0x000ff000
};
const byte kInstruction_movs_eq_r2_0xac000002[] = {
  0xab, 0x23, 0xb0, 0x03 // movs eq r2 0xac000002
};
const byte kInstruction_movs_le_r11_0x2ac00000[] = {
  0xab, 0xb5, 0xb0, 0xd3 // movs le r11 0x2ac00000
};
const byte kInstruction_movs_le_r8_0xab000000[] = {
  0xab, 0x84, 0xb0, 0xd3 // movs le r8 0xab000000
};
const byte kInstruction_movs_lt_r5_0x02ac0000[] = {
  0xab, 0x57, 0xb0, 0xb3 // movs lt r5 0x02ac0000
};
const byte kInstruction_movs_hi_r13_0x003fc000[] = {
  0xff, 0xd9, 0xb0, 0x83 // movs hi r13 0x003fc000
};
const byte kInstruction_movs_mi_r1_0xfc000003[] = {
  0xff, 0x13, 0xb0, 0x43 // movs mi r1 0xfc000003
};
const byte kInstruction_movs_cc_r4_0x0ab00000[] = {
  0xab, 0x46, 0xb0, 0x33 // movs cc r4 0x0ab00000
};
const byte kInstruction_movs_lt_r7_0x3fc00000[] = {
  0xff, 0x75, 0xb0, 0xb3 // movs lt r7 0x3fc00000
};
const byte kInstruction_movs_lt_r3_0x000002ac[] = {
  0xab, 0x3f, 0xb0, 0xb3 // movs lt r3 0x000002ac
};
const byte kInstruction_movs_pl_r7_0x00000000[] = {
  0x00, 0x70, 0xb0, 0x53 // movs pl r7 0x00000000
};
const byte kInstruction_movs_lt_r2_0x00000000[] = {
  0x00, 0x20, 0xb0, 0xb3 // movs lt r2 0x00000000
};
const byte kInstruction_movs_le_r1_0x0ff00000[] = {
  0xff, 0x16, 0xb0, 0xd3 // movs le r1 0x0ff00000
};
const byte kInstruction_movs_lt_r14_0x0000ff00[] = {
  0xff, 0xec, 0xb0, 0xb3 // movs lt r14 0x0000ff00
};
const byte kInstruction_movs_cs_r11_0x3fc00000[] = {
  0xff, 0xb5, 0xb0, 0x23 // movs cs r11 0x3fc00000
};
const byte kInstruction_movs_ls_r7_0x00000ff0[] = {
  0xff, 0x7e, 0xb0, 0x93 // movs ls r7 0x00000ff0
};
const byte kInstruction_movs_vs_r3_0x0ab00000[] = {
  0xab, 0x36, 0xb0, 0x63 // movs vs r3 0x0ab00000
};
const byte kInstruction_movs_cs_r12_0x0003fc00[] = {
  0xff, 0xcb, 0xb0, 0x23 // movs cs r12 0x0003fc00
};
const byte kInstruction_movs_vc_r3_0xfc000003[] = {
  0xff, 0x33, 0xb0, 0x73 // movs vc r3 0xfc000003
};
const byte kInstruction_movs_vs_r14_0x0ff00000[] = {
  0xff, 0xe6, 0xb0, 0x63 // movs vs r14 0x0ff00000
};
const byte kInstruction_movs_vc_r5_0x00003fc0[] = {
  0xff, 0x5d, 0xb0, 0x73 // movs vc r5 0x00003fc0
};
const byte kInstruction_movs_cc_r14_0x0ff00000[] = {
  0xff, 0xe6, 0xb0, 0x33 // movs cc r14 0x0ff00000
};
const byte kInstruction_movs_cs_r7_0x0ff00000[] = {
  0xff, 0x76, 0xb0, 0x23 // movs cs r7 0x0ff00000
};
const byte kInstruction_movs_al_r2_0x00ab0000[] = {
  0xab, 0x28, 0xb0, 0xe3 // movs al r2 0x00ab0000
};
const byte kInstruction_movs_gt_r0_0x00000000[] = {
  0x00, 0x00, 0xb0, 0xc3 // movs gt r0 0x00000000
};
const byte kInstruction_movs_al_r6_0x000003fc[] = {
  0xff, 0x6f, 0xb0, 0xe3 // movs al r6 0x000003fc
};
const byte kInstruction_movs_ge_r2_0x2ac00000[] = {
  0xab, 0x25, 0xb0, 0xa3 // movs ge r2 0x2ac00000
};
const byte kInstruction_movs_vs_r0_0x03fc0000[] = {
  0xff, 0x07, 0xb0, 0x63 // movs vs r0 0x03fc0000
};
const byte kInstruction_movs_cs_r12_0x00003fc0[] = {
  0xff, 0xcd, 0xb0, 0x23 // movs cs r12 0x00003fc0
};
const byte kInstruction_movs_ge_r3_0x2ac00000[] = {
  0xab, 0x35, 0xb0, 0xa3 // movs ge r3 0x2ac00000
};
const byte kInstruction_movs_le_r13_0x0000ab00[] = {
  0xab, 0xdc, 0xb0, 0xd3 // movs le r13 0x0000ab00
};
const byte kInstruction_movs_al_r13_0x02ac0000[] = {
  0xab, 0xd7, 0xb0, 0xe3 // movs al r13 0x02ac0000
};
const byte kInstruction_movs_mi_r4_0xff000000[] = {
  0xff, 0x44, 0xb0, 0x43 // movs mi r4 0xff000000
};
const byte kInstruction_movs_cs_r3_0x00003fc0[] = {
  0xff, 0x3d, 0xb0, 0x23 // movs cs r3 0x00003fc0
};
const byte kInstruction_movs_ge_r13_0x00ab0000[] = {
  0xab, 0xd8, 0xb0, 0xa3 // movs ge r13 0x00ab0000
};
const byte kInstruction_movs_ne_r4_0x00000ab0[] = {
  0xab, 0x4e, 0xb0, 0x13 // movs ne r4 0x00000ab0
};
const byte kInstruction_movs_cc_r3_0xac000002[] = {
  0xab, 0x33, 0xb0, 0x33 // movs cc r3 0xac000002
};
const byte kInstruction_movs_pl_r11_0xab000000[] = {
  0xab, 0xb4, 0xb0, 0x53 // movs pl r11 0xab000000
};
const byte kInstruction_movs_eq_r13_0xfc000003[] = {
  0xff, 0xd3, 0xb0, 0x03 // movs eq r13 0xfc000003
};
const byte kInstruction_movs_ne_r5_0xc000003f[] = {
  0xff, 0x51, 0xb0, 0x13 // movs ne r5 0xc000003f
};
const byte kInstruction_movs_hi_r7_0xb000000a[] = {
  0xab, 0x72, 0xb0, 0x83 // movs hi r7 0xb000000a
};
const byte kInstruction_movs_al_r12_0xc000002a[] = {
  0xab, 0xc1, 0xb0, 0xe3 // movs al r12 0xc000002a
};
const byte kInstruction_movs_vs_r8_0xf000000f[] = {
  0xff, 0x82, 0xb0, 0x63 // movs vs r8 0xf000000f
};
const byte kInstruction_movs_cs_r6_0x00ff0000[] = {
  0xff, 0x68, 0xb0, 0x23 // movs cs r6 0x00ff0000
};
const byte kInstruction_movs_vs_r1_0x00002ac0[] = {
  0xab, 0x1d, 0xb0, 0x63 // movs vs r1 0x00002ac0
};
const byte kInstruction_movs_ls_r2_0x0ff00000[] = {
  0xff, 0x26, 0xb0, 0x93 // movs ls r2 0x0ff00000
};
const byte kInstruction_movs_mi_r13_0x0000ab00[] = {
  0xab, 0xdc, 0xb0, 0x43 // movs mi r13 0x0000ab00
};
const byte kInstruction_movs_al_r4_0xff000000[] = {
  0xff, 0x44, 0xb0, 0xe3 // movs al r4 0xff000000
};
const byte kInstruction_movs_ne_r1_0x00002ac0[] = {
  0xab, 0x1d, 0xb0, 0x13 // movs ne r1 0x00002ac0
};
const byte kInstruction_movs_vc_r14_0x000002ac[] = {
  0xab, 0xef, 0xb0, 0x73 // movs vc r14 0x000002ac
};
const byte kInstruction_movs_al_r9_0xb000000a[] = {
  0xab, 0x92, 0xb0, 0xe3 // movs al r9 0xb000000a
};
const byte kInstruction_movs_ne_r9_0x000002ac[] = {
  0xab, 0x9f, 0xb0, 0x13 // movs ne r9 0x000002ac
};
const byte kInstruction_movs_hi_r7_0x0ff00000[] = {
  0xff, 0x76, 0xb0, 0x83 // movs hi r7 0x0ff00000
};
const byte kInstruction_movs_ne_r10_0x000ab000[] = {
  0xab, 0xaa, 0xb0, 0x13 // movs ne r10 0x000ab000
};
const byte kInstruction_movs_vs_r0_0x0003fc00[] = {
  0xff, 0x0b, 0xb0, 0x63 // movs vs r0 0x0003fc00
};
const byte kInstruction_movs_cs_r9_0x002ac000[] = {
  0xab, 0x99, 0xb0, 0x23 // movs cs r9 0x002ac000
};
const byte kInstruction_movs_eq_r3_0x00000ff0[] = {
  0xff, 0x3e, 0xb0, 0x03 // movs eq r3 0x00000ff0
};
const byte kInstruction_movs_lt_r5_0x00ab0000[] = {
  0xab, 0x58, 0xb0, 0xb3 // movs lt r5 0x00ab0000
};
const byte kInstruction_movs_pl_r1_0x00ff0000[] = {
  0xff, 0x18, 0xb0, 0x53 // movs pl r1 0x00ff0000
};
const byte kInstruction_movs_eq_r4_0x0000ab00[] = {
  0xab, 0x4c, 0xb0, 0x03 // movs eq r4 0x0000ab00
};
const byte kInstruction_movs_mi_r13_0x000000ab[] = {
  0xab, 0xd0, 0xb0, 0x43 // movs mi r13 0x000000ab
};
const byte kInstruction_movs_pl_r12_0x00000ff0[] = {
  0xff, 0xce, 0xb0, 0x53 // movs pl r12 0x00000ff0
};
const byte kInstruction_movs_eq_r3_0x00002ac0[] = {
  0xab, 0x3d, 0xb0, 0x03 // movs eq r3 0x00002ac0
};
const byte kInstruction_movs_le_r12_0x002ac000[] = {
  0xab, 0xc9, 0xb0, 0xd3 // movs le r12 0x002ac000
};
const byte kInstruction_movs_ge_r10_0x000002ac[] = {
  0xab, 0xaf, 0xb0, 0xa3 // movs ge r10 0x000002ac
};
const byte kInstruction_movs_vs_r1_0x00ff0000[] = {
  0xff, 0x18, 0xb0, 0x63 // movs vs r1 0x00ff0000
};
const byte kInstruction_movs_pl_r8_0x0000ff00[] = {
  0xff, 0x8c, 0xb0, 0x53 // movs pl r8 0x0000ff00
};
const byte kInstruction_movs_vs_r9_0x000ab000[] = {
  0xab, 0x9a, 0xb0, 0x63 // movs vs r9 0x000ab000
};
const byte kInstruction_movs_ls_r6_0x003fc000[] = {
  0xff, 0x69, 0xb0, 0x93 // movs ls r6 0x003fc000
};
const byte kInstruction_movs_vs_r14_0x0ab00000[] = {
  0xab, 0xe6, 0xb0, 0x63 // movs vs r14 0x0ab00000
};
const byte kInstruction_movs_mi_r14_0xf000000f[] = {
  0xff, 0xe2, 0xb0, 0x43 // movs mi r14 0xf000000f
};
const byte kInstruction_movs_vc_r6_0xf000000f[] = {
  0xff, 0x62, 0xb0, 0x73 // movs vc r6 0xf000000f
};
const byte kInstruction_movs_ne_r4_0x0000ff00[] = {
  0xff, 0x4c, 0xb0, 0x13 // movs ne r4 0x0000ff00
};
const byte kInstruction_movs_gt_r10_0xfc000003[] = {
  0xff, 0xa3, 0xb0, 0xc3 // movs gt r10 0xfc000003
};
const byte kInstruction_movs_cs_r6_0x3fc00000[] = {
  0xff, 0x65, 0xb0, 0x23 // movs cs r6 0x3fc00000
};
const byte kInstruction_movs_al_r10_0x0ff00000[] = {
  0xff, 0xa6, 0xb0, 0xe3 // movs al r10 0x0ff00000
};
const byte kInstruction_movs_pl_r12_0x00000000[] = {
  0x00, 0xc0, 0xb0, 0x53 // movs pl r12 0x00000000
};
const byte kInstruction_movs_cc_r5_0xfc000003[] = {
  0xff, 0x53, 0xb0, 0x33 // movs cc r5 0xfc000003
};
const byte kInstruction_movs_pl_r10_0x0003fc00[] = {
  0xff, 0xab, 0xb0, 0x53 // movs pl r10 0x0003fc00
};
const byte kInstruction_movs_eq_r8_0xac000002[] = {
  0xab, 0x83, 0xb0, 0x03 // movs eq r8 0xac000002
};
const byte kInstruction_movs_vs_r12_0xac000002[] = {
  0xab, 0xc3, 0xb0, 0x63 // movs vs r12 0xac000002
};
const byte kInstruction_movs_ne_r9_0x00ab0000[] = {
  0xab, 0x98, 0xb0, 0x13 // movs ne r9 0x00ab0000
};
const byte kInstruction_movs_al_r1_0x0002ac00[] = {
  0xab, 0x1b, 0xb0, 0xe3 // movs al r1 0x0002ac00
};
const byte kInstruction_movs_ne_r6_0x0000ff00[] = {
  0xff, 0x6c, 0xb0, 0x13 // movs ne r6 0x0000ff00
};
const byte kInstruction_movs_mi_r3_0x03fc0000[] = {
  0xff, 0x37, 0xb0, 0x43 // movs mi r3 0x03fc0000
};
const byte kInstruction_movs_ge_r10_0x0002ac00[] = {
  0xab, 0xab, 0xb0, 0xa3 // movs ge r10 0x0002ac00
};
const byte kInstruction_movs_vc_r5_0xb000000a[] = {
  0xab, 0x52, 0xb0, 0x73 // movs vc r5 0xb000000a
};
const byte kInstruction_movs_pl_r1_0x000003fc[] = {
  0xff, 0x1f, 0xb0, 0x53 // movs pl r1 0x000003fc
};
const byte kInstruction_movs_mi_r2_0x02ac0000[] = {
  0xab, 0x27, 0xb0, 0x43 // movs mi r2 0x02ac0000
};
const byte kInstruction_movs_gt_r7_0x0003fc00[] = {
  0xff, 0x7b, 0xb0, 0xc3 // movs gt r7 0x0003fc00
};
const byte kInstruction_movs_vs_r0_0x00000000[] = {
  0x00, 0x00, 0xb0, 0x63 // movs vs r0 0x00000000
};
const byte kInstruction_movs_vc_r11_0xc000003f[] = {
  0xff, 0xb1, 0xb0, 0x73 // movs vc r11 0xc000003f
};
const byte kInstruction_movs_vc_r13_0x0ab00000[] = {
  0xab, 0xd6, 0xb0, 0x73 // movs vc r13 0x0ab00000
};
const byte kInstruction_movs_ge_r5_0x0002ac00[] = {
  0xab, 0x5b, 0xb0, 0xa3 // movs ge r5 0x0002ac00
};
const byte kInstruction_movs_ge_r8_0xc000003f[] = {
  0xff, 0x81, 0xb0, 0xa3 // movs ge r8 0xc000003f
};
const byte kInstruction_movs_al_r14_0x000002ac[] = {
  0xab, 0xef, 0xb0, 0xe3 // movs al r14 0x000002ac
};
const byte kInstruction_movs_vs_r1_0x00000000[] = {
  0x00, 0x10, 0xb0, 0x63 // movs vs r1 0x00000000
};
const byte kInstruction_movs_vc_r2_0x3fc00000[] = {
  0xff, 0x25, 0xb0, 0x73 // movs vc r2 0x3fc00000
};
const byte kInstruction_movs_ne_r2_0xc000003f[] = {
  0xff, 0x21, 0xb0, 0x13 // movs ne r2 0xc000003f
};
const byte kInstruction_movs_cs_r0_0x0ab00000[] = {
  0xab, 0x06, 0xb0, 0x23 // movs cs r0 0x0ab00000
};
const byte kInstruction_movs_le_r5_0xfc000003[] = {
  0xff, 0x53, 0xb0, 0xd3 // movs le r5 0xfc000003
};
const byte kInstruction_movs_cs_r3_0x000002ac[] = {
  0xab, 0x3f, 0xb0, 0x23 // movs cs r3 0x000002ac
};
const byte kInstruction_movs_hi_r3_0x0000ab00[] = {
  0xab, 0x3c, 0xb0, 0x83 // movs hi r3 0x0000ab00
};
const byte kInstruction_movs_ge_r9_0x00ab0000[] = {
  0xab, 0x98, 0xb0, 0xa3 // movs ge r9 0x00ab0000
};
const byte kInstruction_movs_le_r0_0x000ab000[] = {
  0xab, 0x0a, 0xb0, 0xd3 // movs le r0 0x000ab000
};
const byte kInstruction_movs_cc_r7_0x000003fc[] = {
  0xff, 0x7f, 0xb0, 0x33 // movs cc r7 0x000003fc
};
const byte kInstruction_movs_pl_r7_0x00002ac0[] = {
  0xab, 0x7d, 0xb0, 0x53 // movs pl r7 0x00002ac0
};
const byte kInstruction_movs_cc_r1_0x00000ab0[] = {
  0xab, 0x1e, 0xb0, 0x33 // movs cc r1 0x00000ab0
};
const byte kInstruction_movs_le_r8_0x0002ac00[] = {
  0xab, 0x8b, 0xb0, 0xd3 // movs le r8 0x0002ac00
};
const byte kInstruction_movs_mi_r9_0x0003fc00[] = {
  0xff, 0x9b, 0xb0, 0x43 // movs mi r9 0x0003fc00
};
const byte kInstruction_movs_cs_r2_0x000002ac[] = {
  0xab, 0x2f, 0xb0, 0x23 // movs cs r2 0x000002ac
};
const byte kInstruction_movs_vc_r2_0xb000000a[] = {
  0xab, 0x22, 0xb0, 0x73 // movs vc r2 0xb000000a
};
const byte kInstruction_movs_pl_r4_0x000ab000[] = {
  0xab, 0x4a, 0xb0, 0x53 // movs pl r4 0x000ab000
};
const byte kInstruction_movs_hi_r0_0x0003fc00[] = {
  0xff, 0x0b, 0xb0, 0x83 // movs hi r0 0x0003fc00
};
const byte kInstruction_movs_vs_r12_0x000ab000[] = {
  0xab, 0xca, 0xb0, 0x63 // movs vs r12 0x000ab000
};
const byte kInstruction_movs_lt_r9_0x0003fc00[] = {
  0xff, 0x9b, 0xb0, 0xb3 // movs lt r9 0x0003fc00
};
const byte kInstruction_movs_mi_r11_0x00002ac0[] = {
  0xab, 0xbd, 0xb0, 0x43 // movs mi r11 0x00002ac0
};
const byte kInstruction_movs_ls_r13_0x000ab000[] = {
  0xab, 0xda, 0xb0, 0x93 // movs ls r13 0x000ab000
};
const byte kInstruction_movs_al_r3_0x3fc00000[] = {
  0xff, 0x35, 0xb0, 0xe3 // movs al r3 0x3fc00000
};
const byte kInstruction_movs_eq_r14_0x000000ff[] = {
  0xff, 0xe0, 0xb0, 0x03 // movs eq r14 0x000000ff
};
const byte kInstruction_movs_le_r12_0xff000000[] = {
  0xff, 0xc4, 0xb0, 0xd3 // movs le r12 0xff000000
};
const byte kInstruction_movs_gt_r8_0xff000000[] = {
  0xff, 0x84, 0xb0, 0xc3 // movs gt r8 0xff000000
};
const byte kInstruction_movs_eq_r0_0x00ff0000[] = {
  0xff, 0x08, 0xb0, 0x03 // movs eq r0 0x00ff0000
};
const byte kInstruction_movs_cc_r5_0xff000000[] = {
  0xff, 0x54, 0xb0, 0x33 // movs cc r5 0xff000000
};
const byte kInstruction_movs_mi_r2_0x0003fc00[] = {
  0xff, 0x2b, 0xb0, 0x43 // movs mi r2 0x0003fc00
};
const byte kInstruction_movs_cs_r10_0xf000000f[] = {
  0xff, 0xa2, 0xb0, 0x23 // movs cs r10 0xf000000f
};
const byte kInstruction_movs_eq_r0_0xab000000[] = {
  0xab, 0x04, 0xb0, 0x03 // movs eq r0 0xab000000
};
const byte kInstruction_movs_al_r1_0x03fc0000[] = {
  0xff, 0x17, 0xb0, 0xe3 // movs al r1 0x03fc0000
};
const byte kInstruction_movs_ne_r5_0xff000000[] = {
  0xff, 0x54, 0xb0, 0x13 // movs ne r5 0xff000000
};
const byte kInstruction_movs_ne_r1_0x03fc0000[] = {
  0xff, 0x17, 0xb0, 0x13 // movs ne r1 0x03fc0000
};
const byte kInstruction_movs_ls_r1_0x000ff000[] = {
  0xff, 0x1a, 0xb0, 0x93 // movs ls r1 0x000ff000
};
const byte kInstruction_movs_vc_r0_0x00003fc0[] = {
  0xff, 0x0d, 0xb0, 0x73 // movs vc r0 0x00003fc0
};
const byte kInstruction_movs_eq_r4_0x0003fc00[] = {
  0xff, 0x4b, 0xb0, 0x03 // movs eq r4 0x0003fc00
};
const byte kInstruction_movs_mi_r3_0xab000000[] = {
  0xab, 0x34, 0xb0, 0x43 // movs mi r3 0xab000000
};
const byte kInstruction_movs_mi_r5_0xfc000003[] = {
  0xff, 0x53, 0xb0, 0x43 // movs mi r5 0xfc000003
};
const byte kInstruction_movs_vs_r8_0xab000000[] = {
  0xab, 0x84, 0xb0, 0x63 // movs vs r8 0xab000000
};
const byte kInstruction_movs_cs_r9_0x00ff0000[] = {
  0xff, 0x98, 0xb0, 0x23 // movs cs r9 0x00ff0000
};
const byte kInstruction_movs_ge_r7_0x00000ab0[] = {
  0xab, 0x7e, 0xb0, 0xa3 // movs ge r7 0x00000ab0
};
const byte kInstruction_movs_al_r9_0xf000000f[] = {
  0xff, 0x92, 0xb0, 0xe3 // movs al r9 0xf000000f
};
const byte kInstruction_movs_vc_r10_0x000000ff[] = {
  0xff, 0xa0, 0xb0, 0x73 // movs vc r10 0x000000ff
};
const byte kInstruction_movs_al_r4_0x00ab0000[] = {
  0xab, 0x48, 0xb0, 0xe3 // movs al r4 0x00ab0000
};
const byte kInstruction_movs_ls_r6_0x0000ff00[] = {
  0xff, 0x6c, 0xb0, 0x93 // movs ls r6 0x0000ff00
};
const byte kInstruction_movs_cc_r14_0x0ab00000[] = {
  0xab, 0xe6, 0xb0, 0x33 // movs cc r14 0x0ab00000
};
const byte kInstruction_movs_le_r5_0x3fc00000[] = {
  0xff, 0x55, 0xb0, 0xd3 // movs le r5 0x3fc00000
};
const byte kInstruction_movs_ne_r12_0x0ff00000[] = {
  0xff, 0xc6, 0xb0, 0x13 // movs ne r12 0x0ff00000
};
const byte kInstruction_movs_cc_r11_0xf000000f[] = {
  0xff, 0xb2, 0xb0, 0x33 // movs cc r11 0xf000000f
};
const byte kInstruction_movs_lt_r9_0x000003fc[] = {
  0xff, 0x9f, 0xb0, 0xb3 // movs lt r9 0x000003fc
};
const byte kInstruction_movs_ne_r7_0x000002ac[] = {
  0xab, 0x7f, 0xb0, 0x13 // movs ne r7 0x000002ac
};
const byte kInstruction_movs_ge_r5_0x00003fc0[] = {
  0xff, 0x5d, 0xb0, 0xa3 // movs ge r5 0x00003fc0
};
const byte kInstruction_movs_lt_r14_0x00002ac0[] = {
  0xab, 0xed, 0xb0, 0xb3 // movs lt r14 0x00002ac0
};
const byte kInstruction_movs_vs_r8_0x0002ac00[] = {
  0xab, 0x8b, 0xb0, 0x63 // movs vs r8 0x0002ac00
};
const byte kInstruction_movs_gt_r7_0x0000ff00[] = {
  0xff, 0x7c, 0xb0, 0xc3 // movs gt r7 0x0000ff00
};
const byte kInstruction_movs_gt_r11_0x000002ac[] = {
  0xab, 0xbf, 0xb0, 0xc3 // movs gt r11 0x000002ac
};
const byte kInstruction_movs_lt_r12_0x00003fc0[] = {
  0xff, 0xcd, 0xb0, 0xb3 // movs lt r12 0x00003fc0
};
const byte kInstruction_movs_gt_r4_0x00ff0000[] = {
  0xff, 0x48, 0xb0, 0xc3 // movs gt r4 0x00ff0000
};
const byte kInstruction_movs_gt_r0_0x000ff000[] = {
  0xff, 0x0a, 0xb0, 0xc3 // movs gt r0 0x000ff000
};
const byte kInstruction_movs_hi_r3_0x0002ac00[] = {
  0xab, 0x3b, 0xb0, 0x83 // movs hi r3 0x0002ac00
};
const byte kInstruction_movs_al_r6_0x003fc000[] = {
  0xff, 0x69, 0xb0, 0xe3 // movs al r6 0x003fc000
};
const byte kInstruction_movs_al_r5_0x0003fc00[] = {
  0xff, 0x5b, 0xb0, 0xe3 // movs al r5 0x0003fc00
};
const byte kInstruction_movs_mi_r14_0x03fc0000[] = {
  0xff, 0xe7, 0xb0, 0x43 // movs mi r14 0x03fc0000
};
const byte kInstruction_movs_le_r10_0x0ab00000[] = {
  0xab, 0xa6, 0xb0, 0xd3 // movs le r10 0x0ab00000
};
const byte kInstruction_movs_vc_r4_0xab000000[] = {
  0xab, 0x44, 0xb0, 0x73 // movs vc r4 0xab000000
};
const byte kInstruction_movs_lt_r12_0xf000000f[] = {
  0xff, 0xc2, 0xb0, 0xb3 // movs lt r12 0xf000000f
};
const byte kInstruction_movs_le_r12_0xf000000f[] = {
  0xff, 0xc2, 0xb0, 0xd3 // movs le r12 0xf000000f
};
const byte kInstruction_movs_pl_r3_0xfc000003[] = {
  0xff, 0x33, 0xb0, 0x53 // movs pl r3 0xfc000003
};
const byte kInstruction_movs_ls_r9_0x000003fc[] = {
  0xff, 0x9f, 0xb0, 0x93 // movs ls r9 0x000003fc
};
const byte kInstruction_movs_hi_r0_0x00ff0000[] = {
  0xff, 0x08, 0xb0, 0x83 // movs hi r0 0x00ff0000
};
const byte kInstruction_movs_ge_r5_0x000000ab[] = {
  0xab, 0x50, 0xb0, 0xa3 // movs ge r5 0x000000ab
};
const byte kInstruction_movs_pl_r1_0x00000000[] = {
  0x00, 0x10, 0xb0, 0x53 // movs pl r1 0x00000000
};
const byte kInstruction_movs_vs_r11_0x0002ac00[] = {
  0xab, 0xbb, 0xb0, 0x63 // movs vs r11 0x0002ac00
};
const byte kInstruction_movs_cc_r10_0xac000002[] = {
  0xab, 0xa3, 0xb0, 0x33 // movs cc r10 0xac000002
};
const byte kInstruction_movs_al_r2_0x00000000[] = {
  0x00, 0x20, 0xb0, 0xe3 // movs al r2 0x00000000
};
const byte kInstruction_movs_eq_r8_0xab000000[] = {
  0xab, 0x84, 0xb0, 0x03 // movs eq r8 0xab000000
};
const byte kInstruction_movs_al_r5_0xb000000a[] = {
  0xab, 0x52, 0xb0, 0xe3 // movs al r5 0xb000000a
};
const byte kInstruction_movs_cs_r8_0x000003fc[] = {
  0xff, 0x8f, 0xb0, 0x23 // movs cs r8 0x000003fc
};
const byte kInstruction_movs_ge_r5_0xc000003f[] = {
  0xff, 0x51, 0xb0, 0xa3 // movs ge r5 0xc000003f
};
const byte kInstruction_movs_eq_r5_0x00000ff0[] = {
  0xff, 0x5e, 0xb0, 0x03 // movs eq r5 0x00000ff0
};
const byte kInstruction_movs_eq_r5_0x000ff000[] = {
  0xff, 0x5a, 0xb0, 0x03 // movs eq r5 0x000ff000
};
const byte kInstruction_movs_ls_r7_0x00000000[] = {
  0x00, 0x70, 0xb0, 0x93 // movs ls r7 0x00000000
};
const byte kInstruction_movs_vc_r9_0x00ff0000[] = {
  0xff, 0x98, 0xb0, 0x73 // movs vc r9 0x00ff0000
};
const byte kInstruction_movs_le_r6_0x00000ff0[] = {
  0xff, 0x6e, 0xb0, 0xd3 // movs le r6 0x00000ff0
};
const byte kInstruction_movs_pl_r10_0xac000002[] = {
  0xab, 0xa3, 0xb0, 0x53 // movs pl r10 0xac000002
};
const byte kInstruction_movs_vs_r13_0x3fc00000[] = {
  0xff, 0xd5, 0xb0, 0x63 // movs vs r13 0x3fc00000
};
const byte kInstruction_movs_gt_r12_0x000ab000[] = {
  0xab, 0xca, 0xb0, 0xc3 // movs gt r12 0x000ab000
};
const byte kInstruction_movs_pl_r7_0x0000ff00[] = {
  0xff, 0x7c, 0xb0, 0x53 // movs pl r7 0x0000ff00
};
const byte kInstruction_movs_hi_r13_0xab000000[] = {
  0xab, 0xd4, 0xb0, 0x83 // movs hi r13 0xab000000
};
const byte kInstruction_movs_vc_r3_0x00003fc0[] = {
  0xff, 0x3d, 0xb0, 0x73 // movs vc r3 0x00003fc0
};
const byte kInstruction_movs_eq_r8_0x03fc0000[] = {
  0xff, 0x87, 0xb0, 0x03 // movs eq r8 0x03fc0000
};
const byte kInstruction_movs_ge_r7_0x00ab0000[] = {
  0xab, 0x78, 0xb0, 0xa3 // movs ge r7 0x00ab0000
};
const byte kInstruction_movs_ls_r5_0x00000ab0[] = {
  0xab, 0x5e, 0xb0, 0x93 // movs ls r5 0x00000ab0
};
const byte kInstruction_movs_ls_r8_0xb000000a[] = {
  0xab, 0x82, 0xb0, 0x93 // movs ls r8 0xb000000a
};
const byte kInstruction_movs_cs_r2_0xab000000[] = {
  0xab, 0x24, 0xb0, 0x23 // movs cs r2 0xab000000
};
const byte kInstruction_movs_ne_r1_0x0ab00000[] = {
  0xab, 0x16, 0xb0, 0x13 // movs ne r1 0x0ab00000
};
const byte kInstruction_movs_hi_r3_0x0ab00000[] = {
  0xab, 0x36, 0xb0, 0x83 // movs hi r3 0x0ab00000
};
const byte kInstruction_movs_vc_r1_0x00ab0000[] = {
  0xab, 0x18, 0xb0, 0x73 // movs vc r1 0x00ab0000
};
const byte kInstruction_movs_gt_r12_0x0003fc00[] = {
  0xff, 0xcb, 0xb0, 0xc3 // movs gt r12 0x0003fc00
};
const byte kInstruction_movs_lt_r11_0x00000ff0[] = {
  0xff, 0xbe, 0xb0, 0xb3 // movs lt r11 0x00000ff0
};
const byte kInstruction_movs_ne_r5_0xc000002a[] = {
  0xab, 0x51, 0xb0, 0x13 // movs ne r5 0xc000002a
};
const byte kInstruction_movs_vc_r6_0x000003fc[] = {
  0xff, 0x6f, 0xb0, 0x73 // movs vc r6 0x000003fc
};
const byte kInstruction_movs_gt_r1_0xab000000[] = {
  0xab, 0x14, 0xb0, 0xc3 // movs gt r1 0xab000000
};
const byte kInstruction_movs_gt_r5_0x3fc00000[] = {
  0xff, 0x55, 0xb0, 0xc3 // movs gt r5 0x3fc00000
};
const byte kInstruction_movs_cs_r3_0x00002ac0[] = {
  0xab, 0x3d, 0xb0, 0x23 // movs cs r3 0x00002ac0
};
const byte kInstruction_movs_mi_r0_0xff000000[] = {
  0xff, 0x04, 0xb0, 0x43 // movs mi r0 0xff000000
};
const byte kInstruction_movs_cs_r3_0x00000ff0[] = {
  0xff, 0x3e, 0xb0, 0x23 // movs cs r3 0x00000ff0
};
const byte kInstruction_movs_le_r13_0xff000000[] = {
  0xff, 0xd4, 0xb0, 0xd3 // movs le r13 0xff000000
};
const byte kInstruction_movs_hi_r8_0x00000000[] = {
  0x00, 0x80, 0xb0, 0x83 // movs hi r8 0x00000000
};
const byte kInstruction_movs_vc_r12_0x0002ac00[] = {
  0xab, 0xcb, 0xb0, 0x73 // movs vc r12 0x0002ac00
};
const byte kInstruction_movs_eq_r9_0x00000ff0[] = {
  0xff, 0x9e, 0xb0, 0x03 // movs eq r9 0x00000ff0
};
const byte kInstruction_movs_vc_r14_0x0ff00000[] = {
  0xff, 0xe6, 0xb0, 0x73 // movs vc r14 0x0ff00000
};
const byte kInstruction_movs_hi_r2_0x00ff0000[] = {
  0xff, 0x28, 0xb0, 0x83 // movs hi r2 0x00ff0000
};
const byte kInstruction_movs_al_r2_0x03fc0000[] = {
  0xff, 0x27, 0xb0, 0xe3 // movs al r2 0x03fc0000
};
const byte kInstruction_movs_mi_r14_0x0ab00000[] = {
  0xab, 0xe6, 0xb0, 0x43 // movs mi r14 0x0ab00000
};
const byte kInstruction_movs_vs_r11_0x000ff000[] = {
  0xff, 0xba, 0xb0, 0x63 // movs vs r11 0x000ff000
};
const byte kInstruction_movs_le_r11_0x0003fc00[] = {
  0xff, 0xbb, 0xb0, 0xd3 // movs le r11 0x0003fc00
};
const byte kInstruction_movs_eq_r6_0x002ac000[] = {
  0xab, 0x69, 0xb0, 0x03 // movs eq r6 0x002ac000
};
const byte kInstruction_movs_ne_r12_0xab000000[] = {
  0xab, 0xc4, 0xb0, 0x13 // movs ne r12 0xab000000
};
const byte kInstruction_movs_eq_r4_0x000ff000[] = {
  0xff, 0x4a, 0xb0, 0x03 // movs eq r4 0x000ff000
};
const byte kInstruction_movs_cs_r6_0x000003fc[] = {
  0xff, 0x6f, 0xb0, 0x23 // movs cs r6 0x000003fc
};
const byte kInstruction_movs_le_r13_0xf000000f[] = {
  0xff, 0xd2, 0xb0, 0xd3 // movs le r13 0xf000000f
};
const byte kInstruction_movs_vs_r3_0x02ac0000[] = {
  0xab, 0x37, 0xb0, 0x63 // movs vs r3 0x02ac0000
};
const byte kInstruction_movs_lt_r3_0xab000000[] = {
  0xab, 0x34, 0xb0, 0xb3 // movs lt r3 0xab000000
};
const byte kInstruction_movs_pl_r5_0xab000000[] = {
  0xab, 0x54, 0xb0, 0x53 // movs pl r5 0xab000000
};
const byte kInstruction_movs_mi_r10_0x00002ac0[] = {
  0xab, 0xad, 0xb0, 0x43 // movs mi r10 0x00002ac0
};
const byte kInstruction_movs_vc_r3_0x000000ab[] = {
  0xab, 0x30, 0xb0, 0x73 // movs vc r3 0x000000ab
};
const byte kInstruction_movs_pl_r10_0x02ac0000[] = {
  0xab, 0xa7, 0xb0, 0x53 // movs pl r10 0x02ac0000
};
const byte kInstruction_movs_vs_r11_0x3fc00000[] = {
  0xff, 0xb5, 0xb0, 0x63 // movs vs r11 0x3fc00000
};
const byte kInstruction_movs_cc_r7_0x3fc00000[] = {
  0xff, 0x75, 0xb0, 0x33 // movs cc r7 0x3fc00000
};
const byte kInstruction_movs_cs_r3_0x0000ab00[] = {
  0xab, 0x3c, 0xb0, 0x23 // movs cs r3 0x0000ab00
};
const byte kInstruction_movs_cc_r14_0x02ac0000[] = {
  0xab, 0xe7, 0xb0, 0x33 // movs cc r14 0x02ac0000
};
const byte kInstruction_movs_vs_r0_0x2ac00000[] = {
  0xab, 0x05, 0xb0, 0x63 // movs vs r0 0x2ac00000
};
const byte kInstruction_movs_gt_r13_0x0ff00000[] = {
  0xff, 0xd6, 0xb0, 0xc3 // movs gt r13 0x0ff00000
};
const byte kInstruction_movs_mi_r10_0x2ac00000[] = {
  0xab, 0xa5, 0xb0, 0x43 // movs mi r10 0x2ac00000
};
const byte kInstruction_movs_ls_r2_0x0ab00000[] = {
  0xab, 0x26, 0xb0, 0x93 // movs ls r2 0x0ab00000
};
const byte kInstruction_movs_pl_r10_0x000000ff[] = {
  0xff, 0xa0, 0xb0, 0x53 // movs pl r10 0x000000ff
};
const byte kInstruction_movs_al_r9_0x3fc00000[] = {
  0xff, 0x95, 0xb0, 0xe3 // movs al r9 0x3fc00000
};
const byte kInstruction_movs_vs_r4_0x2ac00000[] = {
  0xab, 0x45, 0xb0, 0x63 // movs vs r4 0x2ac00000
};
const byte kInstruction_movs_vs_r12_0x000ff000[] = {
  0xff, 0xca, 0xb0, 0x63 // movs vs r12 0x000ff000
};
const byte kInstruction_movs_ge_r7_0xc000002a[] = {
  0xab, 0x71, 0xb0, 0xa3 // movs ge r7 0xc000002a
};
const byte kInstruction_movs_vc_r7_0x0002ac00[] = {
  0xab, 0x7b, 0xb0, 0x73 // movs vc r7 0x0002ac00
};
const byte kInstruction_movs_gt_r7_0x000ab000[] = {
  0xab, 0x7a, 0xb0, 0xc3 // movs gt r7 0x000ab000
};
const byte kInstruction_movs_gt_r13_0x000000ab[] = {
  0xab, 0xd0, 0xb0, 0xc3 // movs gt r13 0x000000ab
};
const byte kInstruction_movs_ne_r1_0xfc000003[] = {
  0xff, 0x13, 0xb0, 0x13 // movs ne r1 0xfc000003
};
const byte kInstruction_movs_vc_r14_0x000ab000[] = {
  0xab, 0xea, 0xb0, 0x73 // movs vc r14 0x000ab000
};
const byte kInstruction_movs_gt_r5_0xf000000f[] = {
  0xff, 0x52, 0xb0, 0xc3 // movs gt r5 0xf000000f
};
const byte kInstruction_movs_ge_r6_0x00ff0000[] = {
  0xff, 0x68, 0xb0, 0xa3 // movs ge r6 0x00ff0000
};
const byte kInstruction_movs_ls_r12_0x0000ff00[] = {
  0xff, 0xcc, 0xb0, 0x93 // movs ls r12 0x0000ff00
};
const byte kInstruction_movs_mi_r12_0x03fc0000[] = {
  0xff, 0xc7, 0xb0, 0x43 // movs mi r12 0x03fc0000
};
const byte kInstruction_movs_vs_r10_0x0003fc00[] = {
  0xff, 0xab, 0xb0, 0x63 // movs vs r10 0x0003fc00
};
const byte kInstruction_movs_gt_r6_0x0000ff00[] = {
  0xff, 0x6c, 0xb0, 0xc3 // movs gt r6 0x0000ff00
};
const byte kInstruction_movs_pl_r6_0x00ff0000[] = {
  0xff, 0x68, 0xb0, 0x53 // movs pl r6 0x00ff0000
};
const byte kInstruction_movs_ne_r0_0x002ac000[] = {
  0xab, 0x09, 0xb0, 0x13 // movs ne r0 0x002ac000
};
const byte kInstruction_movs_eq_r2_0x003fc000[] = {
  0xff, 0x29, 0xb0, 0x03 // movs eq r2 0x003fc000
};
const byte kInstruction_movs_ne_r10_0x000003fc[] = {
  0xff, 0xaf, 0xb0, 0x13 // movs ne r10 0x000003fc
};
const byte kInstruction_movs_lt_r10_0x02ac0000[] = {
  0xab, 0xa7, 0xb0, 0xb3 // movs lt r10 0x02ac0000
};
const byte kInstruction_movs_lt_r2_0x000ff000[] = {
  0xff, 0x2a, 0xb0, 0xb3 // movs lt r2 0x000ff000
};
const byte kInstruction_movs_pl_r3_0x0000ab00[] = {
  0xab, 0x3c, 0xb0, 0x53 // movs pl r3 0x0000ab00
};
const byte kInstruction_movs_ge_r9_0xc000003f[] = {
  0xff, 0x91, 0xb0, 0xa3 // movs ge r9 0xc000003f
};
const byte kInstruction_movs_vs_r4_0x000003fc[] = {
  0xff, 0x4f, 0xb0, 0x63 // movs vs r4 0x000003fc
};
const byte kInstruction_movs_hi_r13_0xf000000f[] = {
  0xff, 0xd2, 0xb0, 0x83 // movs hi r13 0xf000000f
};
const byte kInstruction_movs_pl_r1_0x02ac0000[] = {
  0xab, 0x17, 0xb0, 0x53 // movs pl r1 0x02ac0000
};
const byte kInstruction_movs_pl_r1_0x000000ff[] = {
  0xff, 0x10, 0xb0, 0x53 // movs pl r1 0x000000ff
};
const byte kInstruction_movs_al_r3_0x00000ff0[] = {
  0xff, 0x3e, 0xb0, 0xe3 // movs al r3 0x00000ff0
};
const byte kInstruction_movs_gt_r0_0x03fc0000[] = {
  0xff, 0x07, 0xb0, 0xc3 // movs gt r0 0x03fc0000
};
const byte kInstruction_movs_cc_r1_0x2ac00000[] = {
  0xab, 0x15, 0xb0, 0x33 // movs cc r1 0x2ac00000
};
const byte kInstruction_movs_mi_r9_0xc000003f[] = {
  0xff, 0x91, 0xb0, 0x43 // movs mi r9 0xc000003f
};
const byte kInstruction_movs_vc_r4_0xff000000[] = {
  0xff, 0x44, 0xb0, 0x73 // movs vc r4 0xff000000
};
const byte kInstruction_movs_pl_r9_0x0002ac00[] = {
  0xab, 0x9b, 0xb0, 0x53 // movs pl r9 0x0002ac00
};
const byte kInstruction_movs_vs_r8_0x02ac0000[] = {
  0xab, 0x87, 0xb0, 0x63 // movs vs r8 0x02ac0000
};
const byte kInstruction_movs_gt_r7_0xf000000f[] = {
  0xff, 0x72, 0xb0, 0xc3 // movs gt r7 0xf000000f
};
const byte kInstruction_movs_gt_r10_0xff000000[] = {
  0xff, 0xa4, 0xb0, 0xc3 // movs gt r10 0xff000000
};
const byte kInstruction_movs_cs_r0_0x00003fc0[] = {
  0xff, 0x0d, 0xb0, 0x23 // movs cs r0 0x00003fc0
};
const byte kInstruction_movs_gt_r8_0x03fc0000[] = {
  0xff, 0x87, 0xb0, 0xc3 // movs gt r8 0x03fc0000
};
const byte kInstruction_movs_ne_r8_0x00002ac0[] = {
  0xab, 0x8d, 0xb0, 0x13 // movs ne r8 0x00002ac0
};
const byte kInstruction_movs_ne_r13_0xc000002a[] = {
  0xab, 0xd1, 0xb0, 0x13 // movs ne r13 0xc000002a
};
const byte kInstruction_movs_ne_r8_0x3fc00000[] = {
  0xff, 0x85, 0xb0, 0x13 // movs ne r8 0x3fc00000
};
const byte kInstruction_movs_vs_r2_0x002ac000[] = {
  0xab, 0x29, 0xb0, 0x63 // movs vs r2 0x002ac000
};
const byte kInstruction_movs_vs_r7_0x000000ab[] = {
  0xab, 0x70, 0xb0, 0x63 // movs vs r7 0x000000ab
};
const byte kInstruction_movs_cc_r6_0x00000000[] = {
  0x00, 0x60, 0xb0, 0x33 // movs cc r6 0x00000000
};
const byte kInstruction_movs_ls_r3_0xf000000f[] = {
  0xff, 0x32, 0xb0, 0x93 // movs ls r3 0xf000000f
};
const byte kInstruction_movs_hi_r0_0x000000ff[] = {
  0xff, 0x00, 0xb0, 0x83 // movs hi r0 0x000000ff
};
const byte kInstruction_movs_cs_r6_0x00002ac0[] = {
  0xab, 0x6d, 0xb0, 0x23 // movs cs r6 0x00002ac0
};
const byte kInstruction_movs_al_r1_0xb000000a[] = {
  0xab, 0x12, 0xb0, 0xe3 // movs al r1 0xb000000a
};
const byte kInstruction_movs_cc_r0_0x00002ac0[] = {
  0xab, 0x0d, 0xb0, 0x33 // movs cc r0 0x00002ac0
};
const byte kInstruction_movs_cc_r12_0x000003fc[] = {
  0xff, 0xcf, 0xb0, 0x33 // movs cc r12 0x000003fc
};
const byte kInstruction_movs_ne_r14_0xc000002a[] = {
  0xab, 0xe1, 0xb0, 0x13 // movs ne r14 0xc000002a
};
const byte kInstruction_movs_al_r6_0xc000003f[] = {
  0xff, 0x61, 0xb0, 0xe3 // movs al r6 0xc000003f
};
const byte kInstruction_movs_ls_r5_0xf000000f[] = {
  0xff, 0x52, 0xb0, 0x93 // movs ls r5 0xf000000f
};
const byte kInstruction_movs_mi_r5_0x03fc0000[] = {
  0xff, 0x57, 0xb0, 0x43 // movs mi r5 0x03fc0000
};
const byte kInstruction_movs_cs_r14_0xf000000f[] = {
  0xff, 0xe2, 0xb0, 0x23 // movs cs r14 0xf000000f
};
const byte kInstruction_movs_hi_r0_0x02ac0000[] = {
  0xab, 0x07, 0xb0, 0x83 // movs hi r0 0x02ac0000
};
const byte kInstruction_movs_pl_r10_0x00000000[] = {
  0x00, 0xa0, 0xb0, 0x53 // movs pl r10 0x00000000
};
const byte kInstruction_movs_ne_r6_0xc000003f[] = {
  0xff, 0x61, 0xb0, 0x13 // movs ne r6 0xc000003f
};
const byte kInstruction_movs_mi_r6_0x00002ac0[] = {
  0xab, 0x6d, 0xb0, 0x43 // movs mi r6 0x00002ac0
};
const byte kInstruction_movs_vs_r6_0x000000ab[] = {
  0xab, 0x60, 0xb0, 0x63 // movs vs r6 0x000000ab
};
const byte kInstruction_movs_vc_r6_0x3fc00000[] = {
  0xff, 0x65, 0xb0, 0x73 // movs vc r6 0x3fc00000
};
const byte kInstruction_movs_al_r10_0x3fc00000[] = {
  0xff, 0xa5, 0xb0, 0xe3 // movs al r10 0x3fc00000
};
const byte kInstruction_movs_eq_r7_0xc000003f[] = {
  0xff, 0x71, 0xb0, 0x03 // movs eq r7 0xc000003f
};
const byte kInstruction_movs_vs_r9_0x02ac0000[] = {
  0xab, 0x97, 0xb0, 0x63 // movs vs r9 0x02ac0000
};
const byte kInstruction_movs_mi_r6_0xac000002[] = {
  0xab, 0x63, 0xb0, 0x43 // movs mi r6 0xac000002
};
const byte kInstruction_movs_vc_r8_0xc000002a[] = {
  0xab, 0x81, 0xb0, 0x73 // movs vc r8 0xc000002a
};
const byte kInstruction_movs_pl_r2_0x0000ab00[] = {
  0xab, 0x2c, 0xb0, 0x53 // movs pl r2 0x0000ab00
};
const byte kInstruction_movs_hi_r4_0x00000ff0[] = {
  0xff, 0x4e, 0xb0, 0x83 // movs hi r4 0x00000ff0
};
const byte kInstruction_movs_al_r8_0x003fc000[] = {
  0xff, 0x89, 0xb0, 0xe3 // movs al r8 0x003fc000
};
const byte kInstruction_movs_vs_r12_0xfc000003[] = {
  0xff, 0xc3, 0xb0, 0x63 // movs vs r12 0xfc000003
};
const byte kInstruction_movs_cs_r0_0xac000002[] = {
  0xab, 0x03, 0xb0, 0x23 // movs cs r0 0xac000002
};
const byte kInstruction_movs_mi_r4_0x02ac0000[] = {
  0xab, 0x47, 0xb0, 0x43 // movs mi r4 0x02ac0000
};
const byte kInstruction_movs_pl_r11_0x00003fc0[] = {
  0xff, 0xbd, 0xb0, 0x53 // movs pl r11 0x00003fc0
};
const byte kInstruction_movs_pl_r13_0xac000002[] = {
  0xab, 0xd3, 0xb0, 0x53 // movs pl r13 0xac000002
};
const byte kInstruction_movs_hi_r8_0x0000ff00[] = {
  0xff, 0x8c, 0xb0, 0x83 // movs hi r8 0x0000ff00
};
const byte kInstruction_movs_cs_r13_0x2ac00000[] = {
  0xab, 0xd5, 0xb0, 0x23 // movs cs r13 0x2ac00000
};
const byte kInstruction_movs_hi_r11_0xc000003f[] = {
  0xff, 0xb1, 0xb0, 0x83 // movs hi r11 0xc000003f
};
const byte kInstruction_movs_lt_r5_0x000002ac[] = {
  0xab, 0x5f, 0xb0, 0xb3 // movs lt r5 0x000002ac
};
const byte kInstruction_movs_vs_r4_0x0ff00000[] = {
  0xff, 0x46, 0xb0, 0x63 // movs vs r4 0x0ff00000
};
const byte kInstruction_movs_lt_r2_0x00000ab0[] = {
  0xab, 0x2e, 0xb0, 0xb3 // movs lt r2 0x00000ab0
};
const byte kInstruction_movs_pl_r12_0x000000ab[] = {
  0xab, 0xc0, 0xb0, 0x53 // movs pl r12 0x000000ab
};
const byte kInstruction_movs_gt_r3_0xb000000a[] = {
  0xab, 0x32, 0xb0, 0xc3 // movs gt r3 0xb000000a
};
const byte kInstruction_movs_hi_r12_0x0002ac00[] = {
  0xab, 0xcb, 0xb0, 0x83 // movs hi r12 0x0002ac00
};
const byte kInstruction_movs_le_r0_0x00ff0000[] = {
  0xff, 0x08, 0xb0, 0xd3 // movs le r0 0x00ff0000
};
const byte kInstruction_movs_eq_r6_0x000ab000[] = {
  0xab, 0x6a, 0xb0, 0x03 // movs eq r6 0x000ab000
};
const byte kInstruction_movs_lt_r6_0x0ff00000[] = {
  0xff, 0x66, 0xb0, 0xb3 // movs lt r6 0x0ff00000
};
const byte kInstruction_movs_mi_r4_0x000ff000[] = {
  0xff, 0x4a, 0xb0, 0x43 // movs mi r4 0x000ff000
};
const byte kInstruction_movs_le_r3_0x0ab00000[] = {
  0xab, 0x36, 0xb0, 0xd3 // movs le r3 0x0ab00000
};
const byte kInstruction_movs_ge_r3_0xac000002[] = {
  0xab, 0x33, 0xb0, 0xa3 // movs ge r3 0xac000002
};
const byte kInstruction_movs_gt_r13_0x00000ff0[] = {
  0xff, 0xde, 0xb0, 0xc3 // movs gt r13 0x00000ff0
};
const byte kInstruction_movs_le_r10_0x0000ff00[] = {
  0xff, 0xac, 0xb0, 0xd3 // movs le r10 0x0000ff00
};
const byte kInstruction_movs_lt_r14_0x00ab0000[] = {
  0xab, 0xe8, 0xb0, 0xb3 // movs lt r14 0x00ab0000
};
const byte kInstruction_movs_mi_r2_0x00003fc0[] = {
  0xff, 0x2d, 0xb0, 0x43 // movs mi r2 0x00003fc0
};
const byte kInstruction_movs_ge_r9_0x00002ac0[] = {
  0xab, 0x9d, 0xb0, 0xa3 // movs ge r9 0x00002ac0
};
const byte kInstruction_movs_al_r11_0x2ac00000[] = {
  0xab, 0xb5, 0xb0, 0xe3 // movs al r11 0x2ac00000
};
const byte kInstruction_movs_pl_r6_0x00000000[] = {
  0x00, 0x60, 0xb0, 0x53 // movs pl r6 0x00000000
};
const byte kInstruction_movs_ls_r2_0x002ac000[] = {
  0xab, 0x29, 0xb0, 0x93 // movs ls r2 0x002ac000
};
const byte kInstruction_movs_lt_r0_0xf000000f[] = {
  0xff, 0x02, 0xb0, 0xb3 // movs lt r0 0xf000000f
};
const byte kInstruction_movs_cs_r6_0x00000ff0[] = {
  0xff, 0x6e, 0xb0, 0x23 // movs cs r6 0x00000ff0
};
const byte kInstruction_movs_lt_r12_0x00000ff0[] = {
  0xff, 0xce, 0xb0, 0xb3 // movs lt r12 0x00000ff0
};
const byte kInstruction_movs_al_r6_0xff000000[] = {
  0xff, 0x64, 0xb0, 0xe3 // movs al r6 0xff000000
};
const byte kInstruction_movs_gt_r4_0x0000ff00[] = {
  0xff, 0x4c, 0xb0, 0xc3 // movs gt r4 0x0000ff00
};
const byte kInstruction_movs_al_r14_0x0000ff00[] = {
  0xff, 0xec, 0xb0, 0xe3 // movs al r14 0x0000ff00
};
const byte kInstruction_movs_al_r10_0xf000000f[] = {
  0xff, 0xa2, 0xb0, 0xe3 // movs al r10 0xf000000f
};
const byte kInstruction_movs_mi_r3_0x0003fc00[] = {
  0xff, 0x3b, 0xb0, 0x43 // movs mi r3 0x0003fc00
};
const byte kInstruction_movs_pl_r0_0xf000000f[] = {
  0xff, 0x02, 0xb0, 0x53 // movs pl r0 0xf000000f
};
const byte kInstruction_movs_al_r6_0x00000ab0[] = {
  0xab, 0x6e, 0xb0, 0xe3 // movs al r6 0x00000ab0
};
const byte kInstruction_movs_le_r8_0x000002ac[] = {
  0xab, 0x8f, 0xb0, 0xd3 // movs le r8 0x000002ac
};
const byte kInstruction_movs_ge_r14_0x00000000[] = {
  0x00, 0xe0, 0xb0, 0xa3 // movs ge r14 0x00000000
};
const byte kInstruction_movs_eq_r1_0xff000000[] = {
  0xff, 0x14, 0xb0, 0x03 // movs eq r1 0xff000000
};
const byte kInstruction_movs_mi_r14_0x00000ff0[] = {
  0xff, 0xee, 0xb0, 0x43 // movs mi r14 0x00000ff0
};
const byte kInstruction_movs_eq_r3_0xff000000[] = {
  0xff, 0x34, 0xb0, 0x03 // movs eq r3 0xff000000
};
const byte kInstruction_movs_mi_r0_0x0000ab00[] = {
  0xab, 0x0c, 0xb0, 0x43 // movs mi r0 0x0000ab00
};
const byte kInstruction_movs_mi_r5_0x000ff000[] = {
  0xff, 0x5a, 0xb0, 0x43 // movs mi r5 0x000ff000
};
const byte kInstruction_movs_vs_r3_0x0ff00000[] = {
  0xff, 0x36, 0xb0, 0x63 // movs vs r3 0x0ff00000
};
const byte kInstruction_movs_gt_r14_0x0ff00000[] = {
  0xff, 0xe6, 0xb0, 0xc3 // movs gt r14 0x0ff00000
};
const byte kInstruction_movs_le_r6_0x000003fc[] = {
  0xff, 0x6f, 0xb0, 0xd3 // movs le r6 0x000003fc
};
const byte kInstruction_movs_vs_r6_0xab000000[] = {
  0xab, 0x64, 0xb0, 0x63 // movs vs r6 0xab000000
};
const byte kInstruction_movs_le_r0_0x000000ab[] = {
  0xab, 0x00, 0xb0, 0xd3 // movs le r0 0x000000ab
};
const byte kInstruction_movs_cc_r9_0x0ab00000[] = {
  0xab, 0x96, 0xb0, 0x33 // movs cc r9 0x0ab00000
};
const byte kInstruction_movs_vs_r10_0x0ff00000[] = {
  0xff, 0xa6, 0xb0, 0x63 // movs vs r10 0x0ff00000
};
const byte kInstruction_movs_gt_r3_0x002ac000[] = {
  0xab, 0x39, 0xb0, 0xc3 // movs gt r3 0x002ac000
};
const byte kInstruction_movs_le_r2_0x0ab00000[] = {
  0xab, 0x26, 0xb0, 0xd3 // movs le r2 0x0ab00000
};
const byte kInstruction_movs_ne_r14_0xc000003f[] = {
  0xff, 0xe1, 0xb0, 0x13 // movs ne r14 0xc000003f
};
const byte kInstruction_movs_ne_r14_0x000ff000[] = {
  0xff, 0xea, 0xb0, 0x13 // movs ne r14 0x000ff000
};
const byte kInstruction_movs_hi_r3_0xb000000a[] = {
  0xab, 0x32, 0xb0, 0x83 // movs hi r3 0xb000000a
};
const byte kInstruction_movs_cs_r7_0x000000ab[] = {
  0xab, 0x70, 0xb0, 0x23 // movs cs r7 0x000000ab
};
const byte kInstruction_movs_eq_r12_0x3fc00000[] = {
  0xff, 0xc5, 0xb0, 0x03 // movs eq r12 0x3fc00000
};
const byte kInstruction_movs_ls_r5_0x03fc0000[] = {
  0xff, 0x57, 0xb0, 0x93 // movs ls r5 0x03fc0000
};
const byte kInstruction_movs_ne_r13_0x003fc000[] = {
  0xff, 0xd9, 0xb0, 0x13 // movs ne r13 0x003fc000
};
const byte kInstruction_movs_hi_r6_0xac000002[] = {
  0xab, 0x63, 0xb0, 0x83 // movs hi r6 0xac000002
};
const byte kInstruction_movs_vc_r6_0xfc000003[] = {
  0xff, 0x63, 0xb0, 0x73 // movs vc r6 0xfc000003
};
const byte kInstruction_movs_pl_r10_0x00ab0000[] = {
  0xab, 0xa8, 0xb0, 0x53 // movs pl r10 0x00ab0000
};
const byte kInstruction_movs_vc_r6_0x0000ff00[] = {
  0xff, 0x6c, 0xb0, 0x73 // movs vc r6 0x0000ff00
};
const byte kInstruction_movs_cs_r0_0x003fc000[] = {
  0xff, 0x09, 0xb0, 0x23 // movs cs r0 0x003fc000
};
const byte kInstruction_movs_hi_r5_0x000003fc[] = {
  0xff, 0x5f, 0xb0, 0x83 // movs hi r5 0x000003fc
};
const byte kInstruction_movs_mi_r7_0x0002ac00[] = {
  0xab, 0x7b, 0xb0, 0x43 // movs mi r7 0x0002ac00
};
const byte kInstruction_movs_ne_r0_0x02ac0000[] = {
  0xab, 0x07, 0xb0, 0x13 // movs ne r0 0x02ac0000
};
const byte kInstruction_movs_vs_r12_0xc000002a[] = {
  0xab, 0xc1, 0xb0, 0x63 // movs vs r12 0xc000002a
};
const byte kInstruction_movs_al_r12_0x000002ac[] = {
  0xab, 0xcf, 0xb0, 0xe3 // movs al r12 0x000002ac
};
const byte kInstruction_movs_cs_r4_0x3fc00000[] = {
  0xff, 0x45, 0xb0, 0x23 // movs cs r4 0x3fc00000
};
const byte kInstruction_movs_ne_r9_0x00000ab0[] = {
  0xab, 0x9e, 0xb0, 0x13 // movs ne r9 0x00000ab0
};
const byte kInstruction_movs_eq_r14_0x0003fc00[] = {
  0xff, 0xeb, 0xb0, 0x03 // movs eq r14 0x0003fc00
};
const TestResult kReferencemovs[] = {
  {
    ARRAY_SIZE(kInstruction_movs_ls_r0_0x003fc000),
    kInstruction_movs_ls_r0_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r13_0xff000000),
    kInstruction_movs_eq_r13_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r0_0x0002ac00),
    kInstruction_movs_al_r0_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r13_0x002ac000),
    kInstruction_movs_gt_r13_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r3_0x000002ac),
    kInstruction_movs_mi_r3_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r0_0x000000ff),
    kInstruction_movs_ls_r0_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r7_0x0000ab00),
    kInstruction_movs_ls_r7_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r11_0x0ff00000),
    kInstruction_movs_cc_r11_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r5_0xc000003f),
    kInstruction_movs_vs_r5_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r3_0x00ab0000),
    kInstruction_movs_gt_r3_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r7_0xff000000),
    kInstruction_movs_hi_r7_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r10_0xff000000),
    kInstruction_movs_vc_r10_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r10_0x002ac000),
    kInstruction_movs_hi_r10_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r9_0x00ff0000),
    kInstruction_movs_ne_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r3_0xf000000f),
    kInstruction_movs_ge_r3_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r0_0x000ff000),
    kInstruction_movs_hi_r0_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r2_0x00002ac0),
    kInstruction_movs_mi_r2_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r6_0x000ab000),
    kInstruction_movs_ge_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r9_0x00ff0000),
    kInstruction_movs_mi_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r2_0x000ff000),
    kInstruction_movs_cs_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x003fc000),
    kInstruction_movs_lt_r5_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r1_0x000ff000),
    kInstruction_movs_al_r1_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r6_0x000000ab),
    kInstruction_movs_mi_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r9_0xac000002),
    kInstruction_movs_pl_r9_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r8_0x000ff000),
    kInstruction_movs_hi_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r0_0x00002ac0),
    kInstruction_movs_vs_r0_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r4_0xab000000),
    kInstruction_movs_ls_r4_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r6_0x000ab000),
    kInstruction_movs_vs_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r13_0x0000ab00),
    kInstruction_movs_vc_r13_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r0_0xab000000),
    kInstruction_movs_mi_r0_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r9_0x0ab00000),
    kInstruction_movs_vs_r9_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r0_0x00003fc0),
    kInstruction_movs_pl_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r2_0x0000ff00),
    kInstruction_movs_al_r2_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r11_0x00000ab0),
    kInstruction_movs_gt_r11_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r10_0xac000002),
    kInstruction_movs_vs_r10_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r3_0x0002ac00),
    kInstruction_movs_cs_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r13_0x000000ab),
    kInstruction_movs_vc_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r11_0x003fc000),
    kInstruction_movs_cs_r11_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r14_0x0000ab00),
    kInstruction_movs_vs_r14_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r11_0xfc000003),
    kInstruction_movs_eq_r11_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r13_0x00000ab0),
    kInstruction_movs_pl_r13_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r4_0xb000000a),
    kInstruction_movs_ge_r4_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r12_0x00003fc0),
    kInstruction_movs_pl_r12_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r4_0x0000ff00),
    kInstruction_movs_le_r4_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r4_0x003fc000),
    kInstruction_movs_pl_r4_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r0_0x002ac000),
    kInstruction_movs_hi_r0_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r1_0x00003fc0),
    kInstruction_movs_mi_r1_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r9_0xf000000f),
    kInstruction_movs_hi_r9_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r11_0x0000ab00),
    kInstruction_movs_al_r11_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r6_0x00ab0000),
    kInstruction_movs_ne_r6_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r4_0xff000000),
    kInstruction_movs_lt_r4_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r0_0x0ab00000),
    kInstruction_movs_pl_r0_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r2_0xc000002a),
    kInstruction_movs_ls_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x00003fc0),
    kInstruction_movs_lt_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r5_0x000003fc),
    kInstruction_movs_mi_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r11_0xb000000a),
    kInstruction_movs_ls_r11_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r3_0x0000ff00),
    kInstruction_movs_al_r3_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r3_0xfc000003),
    kInstruction_movs_vs_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r1_0xc000002a),
    kInstruction_movs_ne_r1_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r10_0x0003fc00),
    kInstruction_movs_eq_r10_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r3_0xf000000f),
    kInstruction_movs_eq_r3_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r5_0x000ff000),
    kInstruction_movs_vs_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r12_0x000000ab),
    kInstruction_movs_ge_r12_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r12_0xf000000f),
    kInstruction_movs_vc_r12_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r11_0x02ac0000),
    kInstruction_movs_lt_r11_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r6_0x003fc000),
    kInstruction_movs_vs_r6_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r8_0x3fc00000),
    kInstruction_movs_cs_r8_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r5_0x0002ac00),
    kInstruction_movs_le_r5_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r9_0x0002ac00),
    kInstruction_movs_ls_r9_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r4_0x3fc00000),
    kInstruction_movs_al_r4_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x000000ff),
    kInstruction_movs_lt_r5_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r8_0xc000002a),
    kInstruction_movs_cs_r8_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r0_0x00000ab0),
    kInstruction_movs_cs_r0_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r2_0x3fc00000),
    kInstruction_movs_cs_r2_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r14_0xab000000),
    kInstruction_movs_vs_r14_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r8_0x002ac000),
    kInstruction_movs_ne_r8_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r1_0x003fc000),
    kInstruction_movs_vs_r1_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r7_0x003fc000),
    kInstruction_movs_al_r7_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r7_0x000ab000),
    kInstruction_movs_vs_r7_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r12_0xb000000a),
    kInstruction_movs_vc_r12_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r2_0xc000002a),
    kInstruction_movs_eq_r2_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r4_0x0000ff00),
    kInstruction_movs_lt_r4_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r8_0x2ac00000),
    kInstruction_movs_eq_r8_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r7_0x3fc00000),
    kInstruction_movs_hi_r7_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r13_0x3fc00000),
    kInstruction_movs_mi_r13_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r2_0x0002ac00),
    kInstruction_movs_al_r2_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r13_0xab000000),
    kInstruction_movs_gt_r13_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r3_0x00000ab0),
    kInstruction_movs_vs_r3_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r14_0x00000000),
    kInstruction_movs_mi_r14_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r10_0x3fc00000),
    kInstruction_movs_vs_r10_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r7_0x0ff00000),
    kInstruction_movs_vc_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r3_0xf000000f),
    kInstruction_movs_al_r3_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r12_0x03fc0000),
    kInstruction_movs_cs_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r14_0xab000000),
    kInstruction_movs_hi_r14_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r13_0x000002ac),
    kInstruction_movs_mi_r13_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r8_0x2ac00000),
    kInstruction_movs_ge_r8_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r14_0x000003fc),
    kInstruction_movs_vc_r14_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r4_0x0000ab00),
    kInstruction_movs_mi_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r11_0x0ff00000),
    kInstruction_movs_hi_r11_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r8_0x000ff000),
    kInstruction_movs_gt_r8_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r1_0x3fc00000),
    kInstruction_movs_lt_r1_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r12_0x000000ab),
    kInstruction_movs_mi_r12_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r12_0x000003fc),
    kInstruction_movs_vs_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r10_0x000ff000),
    kInstruction_movs_cs_r10_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r12_0xfc000003),
    kInstruction_movs_mi_r12_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r8_0x000000ff),
    kInstruction_movs_pl_r8_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x00002ac0),
    kInstruction_movs_lt_r5_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r0_0xff000000),
    kInstruction_movs_ge_r0_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r0_0xab000000),
    kInstruction_movs_pl_r0_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r8_0x000ab000),
    kInstruction_movs_ls_r8_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r12_0x00000ff0),
    kInstruction_movs_al_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r5_0x00003fc0),
    kInstruction_movs_hi_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r7_0x0003fc00),
    kInstruction_movs_vs_r7_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r13_0x0ff00000),
    kInstruction_movs_ls_r13_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r7_0x000000ab),
    kInstruction_movs_al_r7_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r6_0x000003fc),
    kInstruction_movs_lt_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r9_0xc000002a),
    kInstruction_movs_mi_r9_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r11_0x003fc000),
    kInstruction_movs_ne_r11_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r4_0x00000ab0),
    kInstruction_movs_cs_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r14_0x2ac00000),
    kInstruction_movs_vc_r14_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r8_0x2ac00000),
    kInstruction_movs_vc_r8_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r10_0x003fc000),
    kInstruction_movs_ge_r10_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r14_0xb000000a),
    kInstruction_movs_lt_r14_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r12_0x000ff000),
    kInstruction_movs_cs_r12_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r2_0xac000002),
    kInstruction_movs_eq_r2_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r11_0x2ac00000),
    kInstruction_movs_le_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r8_0xab000000),
    kInstruction_movs_le_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x02ac0000),
    kInstruction_movs_lt_r5_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r13_0x003fc000),
    kInstruction_movs_hi_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r1_0xfc000003),
    kInstruction_movs_mi_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r4_0x0ab00000),
    kInstruction_movs_cc_r4_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r7_0x3fc00000),
    kInstruction_movs_lt_r7_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r3_0x000002ac),
    kInstruction_movs_lt_r3_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r7_0x00000000),
    kInstruction_movs_pl_r7_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r2_0x00000000),
    kInstruction_movs_lt_r2_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r1_0x0ff00000),
    kInstruction_movs_le_r1_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r14_0x0000ff00),
    kInstruction_movs_lt_r14_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r11_0x3fc00000),
    kInstruction_movs_cs_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r7_0x00000ff0),
    kInstruction_movs_ls_r7_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r3_0x0ab00000),
    kInstruction_movs_vs_r3_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r12_0x0003fc00),
    kInstruction_movs_cs_r12_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r3_0xfc000003),
    kInstruction_movs_vc_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r14_0x0ff00000),
    kInstruction_movs_vs_r14_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r5_0x00003fc0),
    kInstruction_movs_vc_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r14_0x0ff00000),
    kInstruction_movs_cc_r14_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r7_0x0ff00000),
    kInstruction_movs_cs_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r2_0x00ab0000),
    kInstruction_movs_al_r2_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r0_0x00000000),
    kInstruction_movs_gt_r0_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r6_0x000003fc),
    kInstruction_movs_al_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r2_0x2ac00000),
    kInstruction_movs_ge_r2_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r0_0x03fc0000),
    kInstruction_movs_vs_r0_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r12_0x00003fc0),
    kInstruction_movs_cs_r12_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r3_0x2ac00000),
    kInstruction_movs_ge_r3_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r13_0x0000ab00),
    kInstruction_movs_le_r13_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r13_0x02ac0000),
    kInstruction_movs_al_r13_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r4_0xff000000),
    kInstruction_movs_mi_r4_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r3_0x00003fc0),
    kInstruction_movs_cs_r3_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r13_0x00ab0000),
    kInstruction_movs_ge_r13_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r4_0x00000ab0),
    kInstruction_movs_ne_r4_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r3_0xac000002),
    kInstruction_movs_cc_r3_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r11_0xab000000),
    kInstruction_movs_pl_r11_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r13_0xfc000003),
    kInstruction_movs_eq_r13_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r5_0xc000003f),
    kInstruction_movs_ne_r5_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r7_0xb000000a),
    kInstruction_movs_hi_r7_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r12_0xc000002a),
    kInstruction_movs_al_r12_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r8_0xf000000f),
    kInstruction_movs_vs_r8_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r6_0x00ff0000),
    kInstruction_movs_cs_r6_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r1_0x00002ac0),
    kInstruction_movs_vs_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r2_0x0ff00000),
    kInstruction_movs_ls_r2_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r13_0x0000ab00),
    kInstruction_movs_mi_r13_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r4_0xff000000),
    kInstruction_movs_al_r4_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r1_0x00002ac0),
    kInstruction_movs_ne_r1_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r14_0x000002ac),
    kInstruction_movs_vc_r14_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r9_0xb000000a),
    kInstruction_movs_al_r9_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r9_0x000002ac),
    kInstruction_movs_ne_r9_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r7_0x0ff00000),
    kInstruction_movs_hi_r7_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r10_0x000ab000),
    kInstruction_movs_ne_r10_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r0_0x0003fc00),
    kInstruction_movs_vs_r0_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r9_0x002ac000),
    kInstruction_movs_cs_r9_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r3_0x00000ff0),
    kInstruction_movs_eq_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x00ab0000),
    kInstruction_movs_lt_r5_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r1_0x00ff0000),
    kInstruction_movs_pl_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r4_0x0000ab00),
    kInstruction_movs_eq_r4_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r13_0x000000ab),
    kInstruction_movs_mi_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r12_0x00000ff0),
    kInstruction_movs_pl_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r3_0x00002ac0),
    kInstruction_movs_eq_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r12_0x002ac000),
    kInstruction_movs_le_r12_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r10_0x000002ac),
    kInstruction_movs_ge_r10_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r1_0x00ff0000),
    kInstruction_movs_vs_r1_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r8_0x0000ff00),
    kInstruction_movs_pl_r8_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r9_0x000ab000),
    kInstruction_movs_vs_r9_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r6_0x003fc000),
    kInstruction_movs_ls_r6_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r14_0x0ab00000),
    kInstruction_movs_vs_r14_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r14_0xf000000f),
    kInstruction_movs_mi_r14_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r6_0xf000000f),
    kInstruction_movs_vc_r6_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r4_0x0000ff00),
    kInstruction_movs_ne_r4_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r10_0xfc000003),
    kInstruction_movs_gt_r10_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r6_0x3fc00000),
    kInstruction_movs_cs_r6_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r10_0x0ff00000),
    kInstruction_movs_al_r10_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r12_0x00000000),
    kInstruction_movs_pl_r12_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r5_0xfc000003),
    kInstruction_movs_cc_r5_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r10_0x0003fc00),
    kInstruction_movs_pl_r10_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r8_0xac000002),
    kInstruction_movs_eq_r8_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r12_0xac000002),
    kInstruction_movs_vs_r12_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r9_0x00ab0000),
    kInstruction_movs_ne_r9_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r1_0x0002ac00),
    kInstruction_movs_al_r1_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r6_0x0000ff00),
    kInstruction_movs_ne_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r3_0x03fc0000),
    kInstruction_movs_mi_r3_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r10_0x0002ac00),
    kInstruction_movs_ge_r10_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r5_0xb000000a),
    kInstruction_movs_vc_r5_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r1_0x000003fc),
    kInstruction_movs_pl_r1_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r2_0x02ac0000),
    kInstruction_movs_mi_r2_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r7_0x0003fc00),
    kInstruction_movs_gt_r7_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r0_0x00000000),
    kInstruction_movs_vs_r0_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r11_0xc000003f),
    kInstruction_movs_vc_r11_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r13_0x0ab00000),
    kInstruction_movs_vc_r13_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r5_0x0002ac00),
    kInstruction_movs_ge_r5_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r8_0xc000003f),
    kInstruction_movs_ge_r8_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r14_0x000002ac),
    kInstruction_movs_al_r14_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r1_0x00000000),
    kInstruction_movs_vs_r1_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r2_0x3fc00000),
    kInstruction_movs_vc_r2_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r2_0xc000003f),
    kInstruction_movs_ne_r2_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r0_0x0ab00000),
    kInstruction_movs_cs_r0_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r5_0xfc000003),
    kInstruction_movs_le_r5_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r3_0x000002ac),
    kInstruction_movs_cs_r3_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r3_0x0000ab00),
    kInstruction_movs_hi_r3_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r9_0x00ab0000),
    kInstruction_movs_ge_r9_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r0_0x000ab000),
    kInstruction_movs_le_r0_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r7_0x000003fc),
    kInstruction_movs_cc_r7_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r7_0x00002ac0),
    kInstruction_movs_pl_r7_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r1_0x00000ab0),
    kInstruction_movs_cc_r1_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r8_0x0002ac00),
    kInstruction_movs_le_r8_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r9_0x0003fc00),
    kInstruction_movs_mi_r9_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r2_0x000002ac),
    kInstruction_movs_cs_r2_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r2_0xb000000a),
    kInstruction_movs_vc_r2_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r4_0x000ab000),
    kInstruction_movs_pl_r4_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r0_0x0003fc00),
    kInstruction_movs_hi_r0_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r12_0x000ab000),
    kInstruction_movs_vs_r12_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r9_0x0003fc00),
    kInstruction_movs_lt_r9_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r11_0x00002ac0),
    kInstruction_movs_mi_r11_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r13_0x000ab000),
    kInstruction_movs_ls_r13_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r3_0x3fc00000),
    kInstruction_movs_al_r3_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r14_0x000000ff),
    kInstruction_movs_eq_r14_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r12_0xff000000),
    kInstruction_movs_le_r12_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r8_0xff000000),
    kInstruction_movs_gt_r8_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r0_0x00ff0000),
    kInstruction_movs_eq_r0_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r5_0xff000000),
    kInstruction_movs_cc_r5_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r2_0x0003fc00),
    kInstruction_movs_mi_r2_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r10_0xf000000f),
    kInstruction_movs_cs_r10_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r0_0xab000000),
    kInstruction_movs_eq_r0_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r1_0x03fc0000),
    kInstruction_movs_al_r1_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r5_0xff000000),
    kInstruction_movs_ne_r5_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r1_0x03fc0000),
    kInstruction_movs_ne_r1_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r1_0x000ff000),
    kInstruction_movs_ls_r1_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r0_0x00003fc0),
    kInstruction_movs_vc_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r4_0x0003fc00),
    kInstruction_movs_eq_r4_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r3_0xab000000),
    kInstruction_movs_mi_r3_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r5_0xfc000003),
    kInstruction_movs_mi_r5_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r8_0xab000000),
    kInstruction_movs_vs_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r9_0x00ff0000),
    kInstruction_movs_cs_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r7_0x00000ab0),
    kInstruction_movs_ge_r7_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r9_0xf000000f),
    kInstruction_movs_al_r9_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r10_0x000000ff),
    kInstruction_movs_vc_r10_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r4_0x00ab0000),
    kInstruction_movs_al_r4_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r6_0x0000ff00),
    kInstruction_movs_ls_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r14_0x0ab00000),
    kInstruction_movs_cc_r14_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r5_0x3fc00000),
    kInstruction_movs_le_r5_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r12_0x0ff00000),
    kInstruction_movs_ne_r12_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r11_0xf000000f),
    kInstruction_movs_cc_r11_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r9_0x000003fc),
    kInstruction_movs_lt_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r7_0x000002ac),
    kInstruction_movs_ne_r7_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r5_0x00003fc0),
    kInstruction_movs_ge_r5_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r14_0x00002ac0),
    kInstruction_movs_lt_r14_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r8_0x0002ac00),
    kInstruction_movs_vs_r8_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r7_0x0000ff00),
    kInstruction_movs_gt_r7_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r11_0x000002ac),
    kInstruction_movs_gt_r11_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r12_0x00003fc0),
    kInstruction_movs_lt_r12_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r4_0x00ff0000),
    kInstruction_movs_gt_r4_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r0_0x000ff000),
    kInstruction_movs_gt_r0_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r3_0x0002ac00),
    kInstruction_movs_hi_r3_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r6_0x003fc000),
    kInstruction_movs_al_r6_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r5_0x0003fc00),
    kInstruction_movs_al_r5_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r14_0x03fc0000),
    kInstruction_movs_mi_r14_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r10_0x0ab00000),
    kInstruction_movs_le_r10_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r4_0xab000000),
    kInstruction_movs_vc_r4_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r12_0xf000000f),
    kInstruction_movs_lt_r12_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r12_0xf000000f),
    kInstruction_movs_le_r12_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r3_0xfc000003),
    kInstruction_movs_pl_r3_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r9_0x000003fc),
    kInstruction_movs_ls_r9_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r0_0x00ff0000),
    kInstruction_movs_hi_r0_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r5_0x000000ab),
    kInstruction_movs_ge_r5_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r1_0x00000000),
    kInstruction_movs_pl_r1_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r11_0x0002ac00),
    kInstruction_movs_vs_r11_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r10_0xac000002),
    kInstruction_movs_cc_r10_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r2_0x00000000),
    kInstruction_movs_al_r2_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r8_0xab000000),
    kInstruction_movs_eq_r8_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r5_0xb000000a),
    kInstruction_movs_al_r5_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r8_0x000003fc),
    kInstruction_movs_cs_r8_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r5_0xc000003f),
    kInstruction_movs_ge_r5_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r5_0x00000ff0),
    kInstruction_movs_eq_r5_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r5_0x000ff000),
    kInstruction_movs_eq_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r7_0x00000000),
    kInstruction_movs_ls_r7_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r9_0x00ff0000),
    kInstruction_movs_vc_r9_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r6_0x00000ff0),
    kInstruction_movs_le_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r10_0xac000002),
    kInstruction_movs_pl_r10_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r13_0x3fc00000),
    kInstruction_movs_vs_r13_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r12_0x000ab000),
    kInstruction_movs_gt_r12_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r7_0x0000ff00),
    kInstruction_movs_pl_r7_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r13_0xab000000),
    kInstruction_movs_hi_r13_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r3_0x00003fc0),
    kInstruction_movs_vc_r3_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r8_0x03fc0000),
    kInstruction_movs_eq_r8_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r7_0x00ab0000),
    kInstruction_movs_ge_r7_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r5_0x00000ab0),
    kInstruction_movs_ls_r5_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r8_0xb000000a),
    kInstruction_movs_ls_r8_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r2_0xab000000),
    kInstruction_movs_cs_r2_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r1_0x0ab00000),
    kInstruction_movs_ne_r1_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r3_0x0ab00000),
    kInstruction_movs_hi_r3_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r1_0x00ab0000),
    kInstruction_movs_vc_r1_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r12_0x0003fc00),
    kInstruction_movs_gt_r12_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r11_0x00000ff0),
    kInstruction_movs_lt_r11_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r5_0xc000002a),
    kInstruction_movs_ne_r5_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r6_0x000003fc),
    kInstruction_movs_vc_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r1_0xab000000),
    kInstruction_movs_gt_r1_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r5_0x3fc00000),
    kInstruction_movs_gt_r5_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r3_0x00002ac0),
    kInstruction_movs_cs_r3_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r0_0xff000000),
    kInstruction_movs_mi_r0_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r3_0x00000ff0),
    kInstruction_movs_cs_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r13_0xff000000),
    kInstruction_movs_le_r13_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r8_0x00000000),
    kInstruction_movs_hi_r8_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r12_0x0002ac00),
    kInstruction_movs_vc_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r9_0x00000ff0),
    kInstruction_movs_eq_r9_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r14_0x0ff00000),
    kInstruction_movs_vc_r14_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r2_0x00ff0000),
    kInstruction_movs_hi_r2_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r2_0x03fc0000),
    kInstruction_movs_al_r2_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r14_0x0ab00000),
    kInstruction_movs_mi_r14_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r11_0x000ff000),
    kInstruction_movs_vs_r11_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r11_0x0003fc00),
    kInstruction_movs_le_r11_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r6_0x002ac000),
    kInstruction_movs_eq_r6_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r12_0xab000000),
    kInstruction_movs_ne_r12_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r4_0x000ff000),
    kInstruction_movs_eq_r4_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r6_0x000003fc),
    kInstruction_movs_cs_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r13_0xf000000f),
    kInstruction_movs_le_r13_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r3_0x02ac0000),
    kInstruction_movs_vs_r3_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r3_0xab000000),
    kInstruction_movs_lt_r3_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r5_0xab000000),
    kInstruction_movs_pl_r5_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r10_0x00002ac0),
    kInstruction_movs_mi_r10_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r3_0x000000ab),
    kInstruction_movs_vc_r3_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r10_0x02ac0000),
    kInstruction_movs_pl_r10_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r11_0x3fc00000),
    kInstruction_movs_vs_r11_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r7_0x3fc00000),
    kInstruction_movs_cc_r7_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r3_0x0000ab00),
    kInstruction_movs_cs_r3_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r14_0x02ac0000),
    kInstruction_movs_cc_r14_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r0_0x2ac00000),
    kInstruction_movs_vs_r0_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r13_0x0ff00000),
    kInstruction_movs_gt_r13_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r10_0x2ac00000),
    kInstruction_movs_mi_r10_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r2_0x0ab00000),
    kInstruction_movs_ls_r2_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r10_0x000000ff),
    kInstruction_movs_pl_r10_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r9_0x3fc00000),
    kInstruction_movs_al_r9_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r4_0x2ac00000),
    kInstruction_movs_vs_r4_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r12_0x000ff000),
    kInstruction_movs_vs_r12_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r7_0xc000002a),
    kInstruction_movs_ge_r7_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r7_0x0002ac00),
    kInstruction_movs_vc_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r7_0x000ab000),
    kInstruction_movs_gt_r7_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r13_0x000000ab),
    kInstruction_movs_gt_r13_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r1_0xfc000003),
    kInstruction_movs_ne_r1_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r14_0x000ab000),
    kInstruction_movs_vc_r14_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r5_0xf000000f),
    kInstruction_movs_gt_r5_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r6_0x00ff0000),
    kInstruction_movs_ge_r6_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r12_0x0000ff00),
    kInstruction_movs_ls_r12_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r12_0x03fc0000),
    kInstruction_movs_mi_r12_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r10_0x0003fc00),
    kInstruction_movs_vs_r10_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r6_0x0000ff00),
    kInstruction_movs_gt_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r6_0x00ff0000),
    kInstruction_movs_pl_r6_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r0_0x002ac000),
    kInstruction_movs_ne_r0_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r2_0x003fc000),
    kInstruction_movs_eq_r2_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r10_0x000003fc),
    kInstruction_movs_ne_r10_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r10_0x02ac0000),
    kInstruction_movs_lt_r10_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r2_0x000ff000),
    kInstruction_movs_lt_r2_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r3_0x0000ab00),
    kInstruction_movs_pl_r3_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r9_0xc000003f),
    kInstruction_movs_ge_r9_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r4_0x000003fc),
    kInstruction_movs_vs_r4_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r13_0xf000000f),
    kInstruction_movs_hi_r13_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r1_0x02ac0000),
    kInstruction_movs_pl_r1_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r1_0x000000ff),
    kInstruction_movs_pl_r1_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r3_0x00000ff0),
    kInstruction_movs_al_r3_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r0_0x03fc0000),
    kInstruction_movs_gt_r0_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r1_0x2ac00000),
    kInstruction_movs_cc_r1_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r9_0xc000003f),
    kInstruction_movs_mi_r9_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r4_0xff000000),
    kInstruction_movs_vc_r4_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r9_0x0002ac00),
    kInstruction_movs_pl_r9_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r8_0x02ac0000),
    kInstruction_movs_vs_r8_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r7_0xf000000f),
    kInstruction_movs_gt_r7_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r10_0xff000000),
    kInstruction_movs_gt_r10_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r0_0x00003fc0),
    kInstruction_movs_cs_r0_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r8_0x03fc0000),
    kInstruction_movs_gt_r8_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r8_0x00002ac0),
    kInstruction_movs_ne_r8_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r13_0xc000002a),
    kInstruction_movs_ne_r13_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r8_0x3fc00000),
    kInstruction_movs_ne_r8_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r2_0x002ac000),
    kInstruction_movs_vs_r2_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r7_0x000000ab),
    kInstruction_movs_vs_r7_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r6_0x00000000),
    kInstruction_movs_cc_r6_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r3_0xf000000f),
    kInstruction_movs_ls_r3_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r0_0x000000ff),
    kInstruction_movs_hi_r0_0x000000ff,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r6_0x00002ac0),
    kInstruction_movs_cs_r6_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r1_0xb000000a),
    kInstruction_movs_al_r1_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r0_0x00002ac0),
    kInstruction_movs_cc_r0_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r12_0x000003fc),
    kInstruction_movs_cc_r12_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r14_0xc000002a),
    kInstruction_movs_ne_r14_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r6_0xc000003f),
    kInstruction_movs_al_r6_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r5_0xf000000f),
    kInstruction_movs_ls_r5_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r5_0x03fc0000),
    kInstruction_movs_mi_r5_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r14_0xf000000f),
    kInstruction_movs_cs_r14_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r0_0x02ac0000),
    kInstruction_movs_hi_r0_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r10_0x00000000),
    kInstruction_movs_pl_r10_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r6_0xc000003f),
    kInstruction_movs_ne_r6_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r6_0x00002ac0),
    kInstruction_movs_mi_r6_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r6_0x000000ab),
    kInstruction_movs_vs_r6_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r6_0x3fc00000),
    kInstruction_movs_vc_r6_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r10_0x3fc00000),
    kInstruction_movs_al_r10_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r7_0xc000003f),
    kInstruction_movs_eq_r7_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r9_0x02ac0000),
    kInstruction_movs_vs_r9_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r6_0xac000002),
    kInstruction_movs_mi_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r8_0xc000002a),
    kInstruction_movs_vc_r8_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r2_0x0000ab00),
    kInstruction_movs_pl_r2_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r4_0x00000ff0),
    kInstruction_movs_hi_r4_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r8_0x003fc000),
    kInstruction_movs_al_r8_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r12_0xfc000003),
    kInstruction_movs_vs_r12_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r0_0xac000002),
    kInstruction_movs_cs_r0_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r4_0x02ac0000),
    kInstruction_movs_mi_r4_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r11_0x00003fc0),
    kInstruction_movs_pl_r11_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r13_0xac000002),
    kInstruction_movs_pl_r13_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r8_0x0000ff00),
    kInstruction_movs_hi_r8_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r13_0x2ac00000),
    kInstruction_movs_cs_r13_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r11_0xc000003f),
    kInstruction_movs_hi_r11_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r5_0x000002ac),
    kInstruction_movs_lt_r5_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r4_0x0ff00000),
    kInstruction_movs_vs_r4_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r2_0x00000ab0),
    kInstruction_movs_lt_r2_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r12_0x000000ab),
    kInstruction_movs_pl_r12_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r3_0xb000000a),
    kInstruction_movs_gt_r3_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r12_0x0002ac00),
    kInstruction_movs_hi_r12_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r0_0x00ff0000),
    kInstruction_movs_le_r0_0x00ff0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r6_0x000ab000),
    kInstruction_movs_eq_r6_0x000ab000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r6_0x0ff00000),
    kInstruction_movs_lt_r6_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r4_0x000ff000),
    kInstruction_movs_mi_r4_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r3_0x0ab00000),
    kInstruction_movs_le_r3_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r3_0xac000002),
    kInstruction_movs_ge_r3_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r13_0x00000ff0),
    kInstruction_movs_gt_r13_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r10_0x0000ff00),
    kInstruction_movs_le_r10_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r14_0x00ab0000),
    kInstruction_movs_lt_r14_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r2_0x00003fc0),
    kInstruction_movs_mi_r2_0x00003fc0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r9_0x00002ac0),
    kInstruction_movs_ge_r9_0x00002ac0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r11_0x2ac00000),
    kInstruction_movs_al_r11_0x2ac00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r6_0x00000000),
    kInstruction_movs_pl_r6_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r2_0x002ac000),
    kInstruction_movs_ls_r2_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r0_0xf000000f),
    kInstruction_movs_lt_r0_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r6_0x00000ff0),
    kInstruction_movs_cs_r6_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_lt_r12_0x00000ff0),
    kInstruction_movs_lt_r12_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r6_0xff000000),
    kInstruction_movs_al_r6_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r4_0x0000ff00),
    kInstruction_movs_gt_r4_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r14_0x0000ff00),
    kInstruction_movs_al_r14_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r10_0xf000000f),
    kInstruction_movs_al_r10_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r3_0x0003fc00),
    kInstruction_movs_mi_r3_0x0003fc00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r0_0xf000000f),
    kInstruction_movs_pl_r0_0xf000000f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r6_0x00000ab0),
    kInstruction_movs_al_r6_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r8_0x000002ac),
    kInstruction_movs_le_r8_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ge_r14_0x00000000),
    kInstruction_movs_ge_r14_0x00000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r1_0xff000000),
    kInstruction_movs_eq_r1_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r14_0x00000ff0),
    kInstruction_movs_mi_r14_0x00000ff0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r3_0xff000000),
    kInstruction_movs_eq_r3_0xff000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r0_0x0000ab00),
    kInstruction_movs_mi_r0_0x0000ab00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r5_0x000ff000),
    kInstruction_movs_mi_r5_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r3_0x0ff00000),
    kInstruction_movs_vs_r3_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r14_0x0ff00000),
    kInstruction_movs_gt_r14_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r6_0x000003fc),
    kInstruction_movs_le_r6_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r6_0xab000000),
    kInstruction_movs_vs_r6_0xab000000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r0_0x000000ab),
    kInstruction_movs_le_r0_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cc_r9_0x0ab00000),
    kInstruction_movs_cc_r9_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r10_0x0ff00000),
    kInstruction_movs_vs_r10_0x0ff00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_gt_r3_0x002ac000),
    kInstruction_movs_gt_r3_0x002ac000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_le_r2_0x0ab00000),
    kInstruction_movs_le_r2_0x0ab00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r14_0xc000003f),
    kInstruction_movs_ne_r14_0xc000003f,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r14_0x000ff000),
    kInstruction_movs_ne_r14_0x000ff000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r3_0xb000000a),
    kInstruction_movs_hi_r3_0xb000000a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r7_0x000000ab),
    kInstruction_movs_cs_r7_0x000000ab,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r12_0x3fc00000),
    kInstruction_movs_eq_r12_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ls_r5_0x03fc0000),
    kInstruction_movs_ls_r5_0x03fc0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r13_0x003fc000),
    kInstruction_movs_ne_r13_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r6_0xac000002),
    kInstruction_movs_hi_r6_0xac000002,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r6_0xfc000003),
    kInstruction_movs_vc_r6_0xfc000003,
  },
  {
    ARRAY_SIZE(kInstruction_movs_pl_r10_0x00ab0000),
    kInstruction_movs_pl_r10_0x00ab0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vc_r6_0x0000ff00),
    kInstruction_movs_vc_r6_0x0000ff00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r0_0x003fc000),
    kInstruction_movs_cs_r0_0x003fc000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_hi_r5_0x000003fc),
    kInstruction_movs_hi_r5_0x000003fc,
  },
  {
    ARRAY_SIZE(kInstruction_movs_mi_r7_0x0002ac00),
    kInstruction_movs_mi_r7_0x0002ac00,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r0_0x02ac0000),
    kInstruction_movs_ne_r0_0x02ac0000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_vs_r12_0xc000002a),
    kInstruction_movs_vs_r12_0xc000002a,
  },
  {
    ARRAY_SIZE(kInstruction_movs_al_r12_0x000002ac),
    kInstruction_movs_al_r12_0x000002ac,
  },
  {
    ARRAY_SIZE(kInstruction_movs_cs_r4_0x3fc00000),
    kInstruction_movs_cs_r4_0x3fc00000,
  },
  {
    ARRAY_SIZE(kInstruction_movs_ne_r9_0x00000ab0),
    kInstruction_movs_ne_r9_0x00000ab0,
  },
  {
    ARRAY_SIZE(kInstruction_movs_eq_r14_0x0003fc00),
    kInstruction_movs_eq_r14_0x0003fc00,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_OPERAND_CONST_CANNOT_USE_PC_MOVS_A32_H_
